########## MACROS ###########################################################################
#############################################################################################

function(conan_message MESSAGE_OUTPUT)
    if(NOT CONAN_CMAKE_SILENT_OUTPUT)
        message(${ARGV${0}})
    endif()
endfunction()


macro(conan_find_apple_frameworks FRAMEWORKS_FOUND FRAMEWORKS FRAMEWORKS_DIRS)
    if(APPLE)
        foreach(_FRAMEWORK ${FRAMEWORKS})
            # https://cmake.org/pipermail/cmake-developers/2017-August/030199.html
            find_library(CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND NAMES ${_FRAMEWORK} PATHS ${FRAMEWORKS_DIRS} CMAKE_FIND_ROOT_PATH_BOTH)
            if(CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND)
                list(APPEND ${FRAMEWORKS_FOUND} ${CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND})
            else()
                message(FATAL_ERROR "Framework library ${_FRAMEWORK} not found in paths: ${FRAMEWORKS_DIRS}")
            endif()
        endforeach()
    endif()
endmacro()


function(conan_package_library_targets libraries package_libdir deps out_libraries out_libraries_target build_type package_name)
    unset(_CONAN_ACTUAL_TARGETS CACHE)
    unset(_CONAN_FOUND_SYSTEM_LIBS CACHE)
    foreach(_LIBRARY_NAME ${libraries})
        find_library(CONAN_FOUND_LIBRARY NAMES ${_LIBRARY_NAME} PATHS ${package_libdir}
                     NO_DEFAULT_PATH NO_CMAKE_FIND_ROOT_PATH)
        if(CONAN_FOUND_LIBRARY)
            conan_message(STATUS "Library ${_LIBRARY_NAME} found ${CONAN_FOUND_LIBRARY}")
            list(APPEND _out_libraries ${CONAN_FOUND_LIBRARY})
            if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
                # Create a micro-target for each lib/a found
                string(REGEX REPLACE "[^A-Za-z0-9.+_-]" "_" _LIBRARY_NAME ${_LIBRARY_NAME})
                set(_LIB_NAME CONAN_LIB::${package_name}_${_LIBRARY_NAME}${build_type})
                if(NOT TARGET ${_LIB_NAME})
                    # Create a micro-target for each lib/a found
                    add_library(${_LIB_NAME} UNKNOWN IMPORTED)
                    set_target_properties(${_LIB_NAME} PROPERTIES IMPORTED_LOCATION ${CONAN_FOUND_LIBRARY})
                    set(_CONAN_ACTUAL_TARGETS ${_CONAN_ACTUAL_TARGETS} ${_LIB_NAME})
                else()
                    conan_message(STATUS "Skipping already existing target: ${_LIB_NAME}")
                endif()
                list(APPEND _out_libraries_target ${_LIB_NAME})
            endif()
            conan_message(STATUS "Found: ${CONAN_FOUND_LIBRARY}")
        else()
            conan_message(STATUS "Library ${_LIBRARY_NAME} not found in package, might be system one")
            list(APPEND _out_libraries_target ${_LIBRARY_NAME})
            list(APPEND _out_libraries ${_LIBRARY_NAME})
            set(_CONAN_FOUND_SYSTEM_LIBS "${_CONAN_FOUND_SYSTEM_LIBS};${_LIBRARY_NAME}")
        endif()
        unset(CONAN_FOUND_LIBRARY CACHE)
    endforeach()

    if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
        # Add all dependencies to all targets
        string(REPLACE " " ";" deps_list "${deps}")
        foreach(_CONAN_ACTUAL_TARGET ${_CONAN_ACTUAL_TARGETS})
            set_property(TARGET ${_CONAN_ACTUAL_TARGET} PROPERTY INTERFACE_LINK_LIBRARIES "${_CONAN_FOUND_SYSTEM_LIBS};${deps_list}")
        endforeach()
    endif()

    set(${out_libraries} ${_out_libraries} PARENT_SCOPE)
    set(${out_libraries_target} ${_out_libraries_target} PARENT_SCOPE)
endfunction()


########### FOUND PACKAGE ###################################################################
#############################################################################################

include(FindPackageHandleStandardArgs)

conan_message(STATUS "Conan: Using autogenerated FindBoost.cmake")
set(Boost_FOUND 1)
set(Boost_VERSION "1.80.0")

find_package_handle_standard_args(Boost REQUIRED_VARS
                                  Boost_VERSION VERSION_VAR Boost_VERSION)
mark_as_advanced(Boost_FOUND Boost_VERSION)

set(Boost_COMPONENTS Boost::boost Boost::contract Boost::coroutine Boost::fiber_numa Boost::fiber Boost::context Boost::graph Boost::iostreams Boost::json Boost::locale Boost::log_setup Boost::log Boost::math_c99 Boost::math_c99f Boost::math_c99l Boost::math_tr1 Boost::math_tr1f Boost::math_tr1l Boost::math Boost::nowide Boost::program_options Boost::random Boost::regex Boost::stacktrace_noop Boost::stacktrace_windbg Boost::stacktrace_windbg_cached Boost::stacktrace Boost::timer Boost::type_erasure Boost::thread Boost::chrono Boost::container Boost::date_time Boost::unit_test_framework Boost::prg_exec_monitor Boost::test_exec_monitor Boost::test Boost::exception Boost::wave Boost::filesystem Boost::atomic Boost::system Boost::wserialization Boost::serialization Boost::_libboost Boost::headers Boost::diagnostic_definitions Boost::disable_autolinking Boost::dynamic_linking)

if(Boost_FIND_COMPONENTS)
    foreach(_FIND_COMPONENT ${Boost_FIND_COMPONENTS})
        list(FIND Boost_COMPONENTS "Boost::${_FIND_COMPONENT}" _index)
        if(${_index} EQUAL -1)
            conan_message(FATAL_ERROR "Conan: Component '${_FIND_COMPONENT}' NOT found in package 'Boost'")
        else()
            conan_message(STATUS "Conan: Component '${_FIND_COMPONENT}' found in package 'Boost'")
        endif()
    endforeach()
endif()

########### VARIABLES #######################################################################
#############################################################################################


set(Boost_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_RES_DIRS )
set(Boost_DEFINITIONS "-DBOOST_STACKTRACE_USE_NOOP"
			"-DBOOST_STACKTRACE_USE_WINDBG"
			"-DBOOST_STACKTRACE_USE_WINDBG_CACHED"
			"-DBOOST_ALL_NO_LIB"
			"-DBOOST_ALL_DYN_LINK")
set(Boost_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)
set(Boost_COMPILE_DEFINITIONS "BOOST_STACKTRACE_USE_NOOP"
			"BOOST_STACKTRACE_USE_WINDBG"
			"BOOST_STACKTRACE_USE_WINDBG_CACHED"
			"BOOST_ALL_NO_LIB"
			"BOOST_ALL_DYN_LINK")
set(Boost_COMPILE_OPTIONS_LIST "" "")
set(Boost_COMPILE_OPTIONS_C "")
set(Boost_COMPILE_OPTIONS_CXX "")
set(Boost_LIBRARIES_TARGETS "") # Will be filled later, if CMake 3
set(Boost_LIBRARIES "") # Will be filled later
set(Boost_LIBS "") # Same as Boost_LIBRARIES
set(Boost_SYSTEM_LIBS ole32 dbgeng bcrypt)
set(Boost_FRAMEWORK_DIRS )
set(Boost_FRAMEWORKS )
set(Boost_FRAMEWORKS_FOUND "") # Will be filled later
set(Boost_BUILD_MODULES_PATHS )

conan_find_apple_frameworks(Boost_FRAMEWORKS_FOUND "${Boost_FRAMEWORKS}" "${Boost_FRAMEWORK_DIRS}")

mark_as_advanced(Boost_INCLUDE_DIRS
                 Boost_INCLUDE_DIR
                 Boost_INCLUDES
                 Boost_DEFINITIONS
                 Boost_LINKER_FLAGS_LIST
                 Boost_COMPILE_DEFINITIONS
                 Boost_COMPILE_OPTIONS_LIST
                 Boost_LIBRARIES
                 Boost_LIBS
                 Boost_LIBRARIES_TARGETS)

# Find the real .lib/.a and add them to Boost_LIBS and Boost_LIBRARY_LIST
set(Boost_LIBRARY_LIST boost_contract boost_coroutine boost_fiber_numa boost_fiber boost_context boost_graph boost_iostreams boost_json boost_locale boost_log_setup boost_log boost_math_c99 boost_math_c99f boost_math_c99l boost_math_tr1 boost_math_tr1f boost_math_tr1l boost_nowide boost_program_options boost_random boost_regex boost_stacktrace_noop boost_stacktrace_windbg boost_stacktrace_windbg_cached boost_timer boost_type_erasure boost_thread boost_chrono boost_container boost_date_time boost_unit_test_framework boost_prg_exec_monitor libboost_test_exec_monitor libboost_exception boost_wave boost_filesystem boost_atomic boost_wserialization boost_serialization)
set(Boost_LIB_DIRS "C:/.conan/67e52c/1/lib")

# Gather all the libraries that should be linked to the targets (do not touch existing variables):
set(_Boost_DEPENDENCIES "${Boost_FRAMEWORKS_FOUND} ${Boost_SYSTEM_LIBS} BZip2::BZip2;ZLIB::ZLIB")

conan_package_library_targets("${Boost_LIBRARY_LIST}"  # libraries
                              "${Boost_LIB_DIRS}"      # package_libdir
                              "${_Boost_DEPENDENCIES}"  # deps
                              Boost_LIBRARIES            # out_libraries
                              Boost_LIBRARIES_TARGETS    # out_libraries_targets
                              ""                          # build_type
                              "Boost")                                      # package_name

set(Boost_LIBS ${Boost_LIBRARIES})

foreach(_FRAMEWORK ${Boost_FRAMEWORKS_FOUND})
    list(APPEND Boost_LIBRARIES_TARGETS ${_FRAMEWORK})
    list(APPEND Boost_LIBRARIES ${_FRAMEWORK})
endforeach()

foreach(_SYSTEM_LIB ${Boost_SYSTEM_LIBS})
    list(APPEND Boost_LIBRARIES_TARGETS ${_SYSTEM_LIB})
    list(APPEND Boost_LIBRARIES ${_SYSTEM_LIB})
endforeach()

# We need to add our requirements too
set(Boost_LIBRARIES_TARGETS "${Boost_LIBRARIES_TARGETS};BZip2::BZip2;ZLIB::ZLIB")
set(Boost_LIBRARIES "${Boost_LIBRARIES};BZip2::BZip2;ZLIB::ZLIB")

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})


########### COMPONENT dynamic_linking VARIABLES #############################################

set(Boost_dynamic_linking_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_dynamic_linking_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_dynamic_linking_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_dynamic_linking_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_dynamic_linking_RES_DIRS )
set(Boost_dynamic_linking_DEFINITIONS "-DBOOST_ALL_DYN_LINK")
set(Boost_dynamic_linking_COMPILE_DEFINITIONS "BOOST_ALL_DYN_LINK")
set(Boost_dynamic_linking_COMPILE_OPTIONS_C "")
set(Boost_dynamic_linking_COMPILE_OPTIONS_CXX "")
set(Boost_dynamic_linking_LIBS )
set(Boost_dynamic_linking_SYSTEM_LIBS )
set(Boost_dynamic_linking_FRAMEWORK_DIRS )
set(Boost_dynamic_linking_FRAMEWORKS )
set(Boost_dynamic_linking_BUILD_MODULES_PATHS )
set(Boost_dynamic_linking_DEPENDENCIES )
set(Boost_dynamic_linking_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT disable_autolinking VARIABLES #############################################

set(Boost_disable_autolinking_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_disable_autolinking_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_disable_autolinking_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_disable_autolinking_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_disable_autolinking_RES_DIRS )
set(Boost_disable_autolinking_DEFINITIONS "-DBOOST_ALL_NO_LIB")
set(Boost_disable_autolinking_COMPILE_DEFINITIONS "BOOST_ALL_NO_LIB")
set(Boost_disable_autolinking_COMPILE_OPTIONS_C "")
set(Boost_disable_autolinking_COMPILE_OPTIONS_CXX "")
set(Boost_disable_autolinking_LIBS )
set(Boost_disable_autolinking_SYSTEM_LIBS )
set(Boost_disable_autolinking_FRAMEWORK_DIRS )
set(Boost_disable_autolinking_FRAMEWORKS )
set(Boost_disable_autolinking_BUILD_MODULES_PATHS )
set(Boost_disable_autolinking_DEPENDENCIES )
set(Boost_disable_autolinking_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT diagnostic_definitions VARIABLES #############################################

set(Boost_diagnostic_definitions_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_diagnostic_definitions_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_diagnostic_definitions_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_diagnostic_definitions_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_diagnostic_definitions_RES_DIRS )
set(Boost_diagnostic_definitions_DEFINITIONS )
set(Boost_diagnostic_definitions_COMPILE_DEFINITIONS )
set(Boost_diagnostic_definitions_COMPILE_OPTIONS_C "")
set(Boost_diagnostic_definitions_COMPILE_OPTIONS_CXX "")
set(Boost_diagnostic_definitions_LIBS )
set(Boost_diagnostic_definitions_SYSTEM_LIBS )
set(Boost_diagnostic_definitions_FRAMEWORK_DIRS )
set(Boost_diagnostic_definitions_FRAMEWORKS )
set(Boost_diagnostic_definitions_BUILD_MODULES_PATHS )
set(Boost_diagnostic_definitions_DEPENDENCIES )
set(Boost_diagnostic_definitions_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT headers VARIABLES #############################################

set(Boost_headers_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_headers_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_headers_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_headers_LIB_DIRS )
set(Boost_headers_RES_DIRS )
set(Boost_headers_DEFINITIONS )
set(Boost_headers_COMPILE_DEFINITIONS )
set(Boost_headers_COMPILE_OPTIONS_C "")
set(Boost_headers_COMPILE_OPTIONS_CXX "")
set(Boost_headers_LIBS )
set(Boost_headers_SYSTEM_LIBS )
set(Boost_headers_FRAMEWORK_DIRS )
set(Boost_headers_FRAMEWORKS )
set(Boost_headers_BUILD_MODULES_PATHS )
set(Boost_headers_DEPENDENCIES Boost::diagnostic_definitions Boost::disable_autolinking Boost::dynamic_linking)
set(Boost_headers_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT _libboost VARIABLES #############################################

set(Boost__libboost_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost__libboost_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost__libboost_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost__libboost_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost__libboost_RES_DIRS )
set(Boost__libboost_DEFINITIONS )
set(Boost__libboost_COMPILE_DEFINITIONS )
set(Boost__libboost_COMPILE_OPTIONS_C "")
set(Boost__libboost_COMPILE_OPTIONS_CXX "")
set(Boost__libboost_LIBS )
set(Boost__libboost_SYSTEM_LIBS bcrypt)
set(Boost__libboost_FRAMEWORK_DIRS )
set(Boost__libboost_FRAMEWORKS )
set(Boost__libboost_BUILD_MODULES_PATHS )
set(Boost__libboost_DEPENDENCIES Boost::headers)
set(Boost__libboost_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT serialization VARIABLES #############################################

set(Boost_serialization_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_serialization_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_serialization_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_serialization_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_serialization_RES_DIRS )
set(Boost_serialization_DEFINITIONS )
set(Boost_serialization_COMPILE_DEFINITIONS )
set(Boost_serialization_COMPILE_OPTIONS_C "")
set(Boost_serialization_COMPILE_OPTIONS_CXX "")
set(Boost_serialization_LIBS boost_serialization)
set(Boost_serialization_SYSTEM_LIBS )
set(Boost_serialization_FRAMEWORK_DIRS )
set(Boost_serialization_FRAMEWORKS )
set(Boost_serialization_BUILD_MODULES_PATHS )
set(Boost_serialization_DEPENDENCIES Boost::_libboost)
set(Boost_serialization_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT wserialization VARIABLES #############################################

set(Boost_wserialization_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_wserialization_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_wserialization_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_wserialization_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_wserialization_RES_DIRS )
set(Boost_wserialization_DEFINITIONS )
set(Boost_wserialization_COMPILE_DEFINITIONS )
set(Boost_wserialization_COMPILE_OPTIONS_C "")
set(Boost_wserialization_COMPILE_OPTIONS_CXX "")
set(Boost_wserialization_LIBS boost_wserialization)
set(Boost_wserialization_SYSTEM_LIBS )
set(Boost_wserialization_FRAMEWORK_DIRS )
set(Boost_wserialization_FRAMEWORKS )
set(Boost_wserialization_BUILD_MODULES_PATHS )
set(Boost_wserialization_DEPENDENCIES Boost::serialization Boost::_libboost)
set(Boost_wserialization_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT system VARIABLES #############################################

set(Boost_system_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_system_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_system_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_system_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_system_RES_DIRS )
set(Boost_system_DEFINITIONS )
set(Boost_system_COMPILE_DEFINITIONS )
set(Boost_system_COMPILE_OPTIONS_C "")
set(Boost_system_COMPILE_OPTIONS_CXX "")
set(Boost_system_LIBS )
set(Boost_system_SYSTEM_LIBS )
set(Boost_system_FRAMEWORK_DIRS )
set(Boost_system_FRAMEWORKS )
set(Boost_system_BUILD_MODULES_PATHS )
set(Boost_system_DEPENDENCIES Boost::_libboost)
set(Boost_system_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT atomic VARIABLES #############################################

set(Boost_atomic_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_atomic_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_atomic_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_atomic_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_atomic_RES_DIRS )
set(Boost_atomic_DEFINITIONS )
set(Boost_atomic_COMPILE_DEFINITIONS )
set(Boost_atomic_COMPILE_OPTIONS_C "")
set(Boost_atomic_COMPILE_OPTIONS_CXX "")
set(Boost_atomic_LIBS boost_atomic)
set(Boost_atomic_SYSTEM_LIBS )
set(Boost_atomic_FRAMEWORK_DIRS )
set(Boost_atomic_FRAMEWORKS )
set(Boost_atomic_BUILD_MODULES_PATHS )
set(Boost_atomic_DEPENDENCIES Boost::_libboost)
set(Boost_atomic_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT filesystem VARIABLES #############################################

set(Boost_filesystem_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_filesystem_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_filesystem_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_filesystem_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_filesystem_RES_DIRS )
set(Boost_filesystem_DEFINITIONS )
set(Boost_filesystem_COMPILE_DEFINITIONS )
set(Boost_filesystem_COMPILE_OPTIONS_C "")
set(Boost_filesystem_COMPILE_OPTIONS_CXX "")
set(Boost_filesystem_LIBS boost_filesystem)
set(Boost_filesystem_SYSTEM_LIBS )
set(Boost_filesystem_FRAMEWORK_DIRS )
set(Boost_filesystem_FRAMEWORKS )
set(Boost_filesystem_BUILD_MODULES_PATHS )
set(Boost_filesystem_DEPENDENCIES Boost::atomic Boost::system Boost::_libboost)
set(Boost_filesystem_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT wave VARIABLES #############################################

set(Boost_wave_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_wave_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_wave_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_wave_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_wave_RES_DIRS )
set(Boost_wave_DEFINITIONS )
set(Boost_wave_COMPILE_DEFINITIONS )
set(Boost_wave_COMPILE_OPTIONS_C "")
set(Boost_wave_COMPILE_OPTIONS_CXX "")
set(Boost_wave_LIBS boost_wave)
set(Boost_wave_SYSTEM_LIBS )
set(Boost_wave_FRAMEWORK_DIRS )
set(Boost_wave_FRAMEWORKS )
set(Boost_wave_BUILD_MODULES_PATHS )
set(Boost_wave_DEPENDENCIES Boost::filesystem Boost::serialization Boost::_libboost)
set(Boost_wave_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT exception VARIABLES #############################################

set(Boost_exception_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_exception_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_exception_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_exception_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_exception_RES_DIRS )
set(Boost_exception_DEFINITIONS )
set(Boost_exception_COMPILE_DEFINITIONS )
set(Boost_exception_COMPILE_OPTIONS_C "")
set(Boost_exception_COMPILE_OPTIONS_CXX "")
set(Boost_exception_LIBS libboost_exception)
set(Boost_exception_SYSTEM_LIBS )
set(Boost_exception_FRAMEWORK_DIRS )
set(Boost_exception_FRAMEWORKS )
set(Boost_exception_BUILD_MODULES_PATHS )
set(Boost_exception_DEPENDENCIES Boost::_libboost)
set(Boost_exception_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT test VARIABLES #############################################

set(Boost_test_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_test_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_test_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_test_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_test_RES_DIRS )
set(Boost_test_DEFINITIONS )
set(Boost_test_COMPILE_DEFINITIONS )
set(Boost_test_COMPILE_OPTIONS_C "")
set(Boost_test_COMPILE_OPTIONS_CXX "")
set(Boost_test_LIBS )
set(Boost_test_SYSTEM_LIBS )
set(Boost_test_FRAMEWORK_DIRS )
set(Boost_test_FRAMEWORKS )
set(Boost_test_BUILD_MODULES_PATHS )
set(Boost_test_DEPENDENCIES Boost::exception Boost::_libboost)
set(Boost_test_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT test_exec_monitor VARIABLES #############################################

set(Boost_test_exec_monitor_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_test_exec_monitor_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_test_exec_monitor_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_test_exec_monitor_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_test_exec_monitor_RES_DIRS )
set(Boost_test_exec_monitor_DEFINITIONS )
set(Boost_test_exec_monitor_COMPILE_DEFINITIONS )
set(Boost_test_exec_monitor_COMPILE_OPTIONS_C "")
set(Boost_test_exec_monitor_COMPILE_OPTIONS_CXX "")
set(Boost_test_exec_monitor_LIBS libboost_test_exec_monitor)
set(Boost_test_exec_monitor_SYSTEM_LIBS )
set(Boost_test_exec_monitor_FRAMEWORK_DIRS )
set(Boost_test_exec_monitor_FRAMEWORKS )
set(Boost_test_exec_monitor_BUILD_MODULES_PATHS )
set(Boost_test_exec_monitor_DEPENDENCIES Boost::test Boost::_libboost)
set(Boost_test_exec_monitor_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT prg_exec_monitor VARIABLES #############################################

set(Boost_prg_exec_monitor_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_prg_exec_monitor_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_prg_exec_monitor_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_prg_exec_monitor_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_prg_exec_monitor_RES_DIRS )
set(Boost_prg_exec_monitor_DEFINITIONS )
set(Boost_prg_exec_monitor_COMPILE_DEFINITIONS )
set(Boost_prg_exec_monitor_COMPILE_OPTIONS_C "")
set(Boost_prg_exec_monitor_COMPILE_OPTIONS_CXX "")
set(Boost_prg_exec_monitor_LIBS boost_prg_exec_monitor)
set(Boost_prg_exec_monitor_SYSTEM_LIBS )
set(Boost_prg_exec_monitor_FRAMEWORK_DIRS )
set(Boost_prg_exec_monitor_FRAMEWORKS )
set(Boost_prg_exec_monitor_BUILD_MODULES_PATHS )
set(Boost_prg_exec_monitor_DEPENDENCIES Boost::test Boost::_libboost)
set(Boost_prg_exec_monitor_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT unit_test_framework VARIABLES #############################################

set(Boost_unit_test_framework_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_unit_test_framework_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_unit_test_framework_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_unit_test_framework_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_unit_test_framework_RES_DIRS )
set(Boost_unit_test_framework_DEFINITIONS )
set(Boost_unit_test_framework_COMPILE_DEFINITIONS )
set(Boost_unit_test_framework_COMPILE_OPTIONS_C "")
set(Boost_unit_test_framework_COMPILE_OPTIONS_CXX "")
set(Boost_unit_test_framework_LIBS boost_unit_test_framework)
set(Boost_unit_test_framework_SYSTEM_LIBS )
set(Boost_unit_test_framework_FRAMEWORK_DIRS )
set(Boost_unit_test_framework_FRAMEWORKS )
set(Boost_unit_test_framework_BUILD_MODULES_PATHS )
set(Boost_unit_test_framework_DEPENDENCIES Boost::prg_exec_monitor Boost::test Boost::test_exec_monitor Boost::_libboost)
set(Boost_unit_test_framework_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT date_time VARIABLES #############################################

set(Boost_date_time_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_date_time_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_date_time_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_date_time_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_date_time_RES_DIRS )
set(Boost_date_time_DEFINITIONS )
set(Boost_date_time_COMPILE_DEFINITIONS )
set(Boost_date_time_COMPILE_OPTIONS_C "")
set(Boost_date_time_COMPILE_OPTIONS_CXX "")
set(Boost_date_time_LIBS boost_date_time)
set(Boost_date_time_SYSTEM_LIBS )
set(Boost_date_time_FRAMEWORK_DIRS )
set(Boost_date_time_FRAMEWORKS )
set(Boost_date_time_BUILD_MODULES_PATHS )
set(Boost_date_time_DEPENDENCIES Boost::_libboost)
set(Boost_date_time_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT container VARIABLES #############################################

set(Boost_container_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_container_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_container_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_container_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_container_RES_DIRS )
set(Boost_container_DEFINITIONS )
set(Boost_container_COMPILE_DEFINITIONS )
set(Boost_container_COMPILE_OPTIONS_C "")
set(Boost_container_COMPILE_OPTIONS_CXX "")
set(Boost_container_LIBS boost_container)
set(Boost_container_SYSTEM_LIBS )
set(Boost_container_FRAMEWORK_DIRS )
set(Boost_container_FRAMEWORKS )
set(Boost_container_BUILD_MODULES_PATHS )
set(Boost_container_DEPENDENCIES Boost::_libboost)
set(Boost_container_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT chrono VARIABLES #############################################

set(Boost_chrono_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_chrono_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_chrono_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_chrono_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_chrono_RES_DIRS )
set(Boost_chrono_DEFINITIONS )
set(Boost_chrono_COMPILE_DEFINITIONS )
set(Boost_chrono_COMPILE_OPTIONS_C "")
set(Boost_chrono_COMPILE_OPTIONS_CXX "")
set(Boost_chrono_LIBS boost_chrono)
set(Boost_chrono_SYSTEM_LIBS )
set(Boost_chrono_FRAMEWORK_DIRS )
set(Boost_chrono_FRAMEWORKS )
set(Boost_chrono_BUILD_MODULES_PATHS )
set(Boost_chrono_DEPENDENCIES Boost::system Boost::_libboost)
set(Boost_chrono_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT thread VARIABLES #############################################

set(Boost_thread_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_thread_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_thread_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_thread_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_thread_RES_DIRS )
set(Boost_thread_DEFINITIONS )
set(Boost_thread_COMPILE_DEFINITIONS )
set(Boost_thread_COMPILE_OPTIONS_C "")
set(Boost_thread_COMPILE_OPTIONS_CXX "")
set(Boost_thread_LIBS boost_thread)
set(Boost_thread_SYSTEM_LIBS )
set(Boost_thread_FRAMEWORK_DIRS )
set(Boost_thread_FRAMEWORKS )
set(Boost_thread_BUILD_MODULES_PATHS )
set(Boost_thread_DEPENDENCIES Boost::atomic Boost::chrono Boost::container Boost::date_time Boost::exception Boost::system Boost::_libboost)
set(Boost_thread_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT type_erasure VARIABLES #############################################

set(Boost_type_erasure_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_type_erasure_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_type_erasure_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_type_erasure_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_type_erasure_RES_DIRS )
set(Boost_type_erasure_DEFINITIONS )
set(Boost_type_erasure_COMPILE_DEFINITIONS )
set(Boost_type_erasure_COMPILE_OPTIONS_C "")
set(Boost_type_erasure_COMPILE_OPTIONS_CXX "")
set(Boost_type_erasure_LIBS boost_type_erasure)
set(Boost_type_erasure_SYSTEM_LIBS )
set(Boost_type_erasure_FRAMEWORK_DIRS )
set(Boost_type_erasure_FRAMEWORKS )
set(Boost_type_erasure_BUILD_MODULES_PATHS )
set(Boost_type_erasure_DEPENDENCIES Boost::thread Boost::_libboost)
set(Boost_type_erasure_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT timer VARIABLES #############################################

set(Boost_timer_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_timer_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_timer_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_timer_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_timer_RES_DIRS )
set(Boost_timer_DEFINITIONS )
set(Boost_timer_COMPILE_DEFINITIONS )
set(Boost_timer_COMPILE_OPTIONS_C "")
set(Boost_timer_COMPILE_OPTIONS_CXX "")
set(Boost_timer_LIBS boost_timer)
set(Boost_timer_SYSTEM_LIBS )
set(Boost_timer_FRAMEWORK_DIRS )
set(Boost_timer_FRAMEWORKS )
set(Boost_timer_BUILD_MODULES_PATHS )
set(Boost_timer_DEPENDENCIES Boost::chrono Boost::system Boost::_libboost)
set(Boost_timer_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT stacktrace VARIABLES #############################################

set(Boost_stacktrace_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_stacktrace_RES_DIRS )
set(Boost_stacktrace_DEFINITIONS )
set(Boost_stacktrace_COMPILE_DEFINITIONS )
set(Boost_stacktrace_COMPILE_OPTIONS_C "")
set(Boost_stacktrace_COMPILE_OPTIONS_CXX "")
set(Boost_stacktrace_LIBS )
set(Boost_stacktrace_SYSTEM_LIBS )
set(Boost_stacktrace_FRAMEWORK_DIRS )
set(Boost_stacktrace_FRAMEWORKS )
set(Boost_stacktrace_BUILD_MODULES_PATHS )
set(Boost_stacktrace_DEPENDENCIES Boost::_libboost)
set(Boost_stacktrace_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT stacktrace_windbg_cached VARIABLES #############################################

set(Boost_stacktrace_windbg_cached_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_cached_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_cached_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_cached_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_stacktrace_windbg_cached_RES_DIRS )
set(Boost_stacktrace_windbg_cached_DEFINITIONS "-DBOOST_STACKTRACE_USE_WINDBG_CACHED")
set(Boost_stacktrace_windbg_cached_COMPILE_DEFINITIONS "BOOST_STACKTRACE_USE_WINDBG_CACHED")
set(Boost_stacktrace_windbg_cached_COMPILE_OPTIONS_C "")
set(Boost_stacktrace_windbg_cached_COMPILE_OPTIONS_CXX "")
set(Boost_stacktrace_windbg_cached_LIBS boost_stacktrace_windbg_cached)
set(Boost_stacktrace_windbg_cached_SYSTEM_LIBS ole32 dbgeng)
set(Boost_stacktrace_windbg_cached_FRAMEWORK_DIRS )
set(Boost_stacktrace_windbg_cached_FRAMEWORKS )
set(Boost_stacktrace_windbg_cached_BUILD_MODULES_PATHS )
set(Boost_stacktrace_windbg_cached_DEPENDENCIES Boost::stacktrace Boost::_libboost)
set(Boost_stacktrace_windbg_cached_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT stacktrace_windbg VARIABLES #############################################

set(Boost_stacktrace_windbg_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_windbg_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_stacktrace_windbg_RES_DIRS )
set(Boost_stacktrace_windbg_DEFINITIONS "-DBOOST_STACKTRACE_USE_WINDBG")
set(Boost_stacktrace_windbg_COMPILE_DEFINITIONS "BOOST_STACKTRACE_USE_WINDBG")
set(Boost_stacktrace_windbg_COMPILE_OPTIONS_C "")
set(Boost_stacktrace_windbg_COMPILE_OPTIONS_CXX "")
set(Boost_stacktrace_windbg_LIBS boost_stacktrace_windbg)
set(Boost_stacktrace_windbg_SYSTEM_LIBS ole32 dbgeng)
set(Boost_stacktrace_windbg_FRAMEWORK_DIRS )
set(Boost_stacktrace_windbg_FRAMEWORKS )
set(Boost_stacktrace_windbg_BUILD_MODULES_PATHS )
set(Boost_stacktrace_windbg_DEPENDENCIES Boost::stacktrace Boost::_libboost)
set(Boost_stacktrace_windbg_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT stacktrace_noop VARIABLES #############################################

set(Boost_stacktrace_noop_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_noop_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_noop_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_stacktrace_noop_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_stacktrace_noop_RES_DIRS )
set(Boost_stacktrace_noop_DEFINITIONS "-DBOOST_STACKTRACE_USE_NOOP")
set(Boost_stacktrace_noop_COMPILE_DEFINITIONS "BOOST_STACKTRACE_USE_NOOP")
set(Boost_stacktrace_noop_COMPILE_OPTIONS_C "")
set(Boost_stacktrace_noop_COMPILE_OPTIONS_CXX "")
set(Boost_stacktrace_noop_LIBS boost_stacktrace_noop)
set(Boost_stacktrace_noop_SYSTEM_LIBS )
set(Boost_stacktrace_noop_FRAMEWORK_DIRS )
set(Boost_stacktrace_noop_FRAMEWORKS )
set(Boost_stacktrace_noop_BUILD_MODULES_PATHS )
set(Boost_stacktrace_noop_DEPENDENCIES Boost::stacktrace Boost::_libboost)
set(Boost_stacktrace_noop_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT regex VARIABLES #############################################

set(Boost_regex_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_regex_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_regex_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_regex_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_regex_RES_DIRS )
set(Boost_regex_DEFINITIONS )
set(Boost_regex_COMPILE_DEFINITIONS )
set(Boost_regex_COMPILE_OPTIONS_C "")
set(Boost_regex_COMPILE_OPTIONS_CXX "")
set(Boost_regex_LIBS boost_regex)
set(Boost_regex_SYSTEM_LIBS )
set(Boost_regex_FRAMEWORK_DIRS )
set(Boost_regex_FRAMEWORKS )
set(Boost_regex_BUILD_MODULES_PATHS )
set(Boost_regex_DEPENDENCIES Boost::_libboost)
set(Boost_regex_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT random VARIABLES #############################################

set(Boost_random_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_random_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_random_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_random_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_random_RES_DIRS )
set(Boost_random_DEFINITIONS )
set(Boost_random_COMPILE_DEFINITIONS )
set(Boost_random_COMPILE_OPTIONS_C "")
set(Boost_random_COMPILE_OPTIONS_CXX "")
set(Boost_random_LIBS boost_random)
set(Boost_random_SYSTEM_LIBS )
set(Boost_random_FRAMEWORK_DIRS )
set(Boost_random_FRAMEWORKS )
set(Boost_random_BUILD_MODULES_PATHS )
set(Boost_random_DEPENDENCIES Boost::system Boost::_libboost)
set(Boost_random_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT program_options VARIABLES #############################################

set(Boost_program_options_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_program_options_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_program_options_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_program_options_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_program_options_RES_DIRS )
set(Boost_program_options_DEFINITIONS )
set(Boost_program_options_COMPILE_DEFINITIONS )
set(Boost_program_options_COMPILE_OPTIONS_C "")
set(Boost_program_options_COMPILE_OPTIONS_CXX "")
set(Boost_program_options_LIBS boost_program_options)
set(Boost_program_options_SYSTEM_LIBS )
set(Boost_program_options_FRAMEWORK_DIRS )
set(Boost_program_options_FRAMEWORKS )
set(Boost_program_options_BUILD_MODULES_PATHS )
set(Boost_program_options_DEPENDENCIES Boost::_libboost)
set(Boost_program_options_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT nowide VARIABLES #############################################

set(Boost_nowide_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_nowide_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_nowide_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_nowide_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_nowide_RES_DIRS )
set(Boost_nowide_DEFINITIONS )
set(Boost_nowide_COMPILE_DEFINITIONS )
set(Boost_nowide_COMPILE_OPTIONS_C "")
set(Boost_nowide_COMPILE_OPTIONS_CXX "")
set(Boost_nowide_LIBS boost_nowide)
set(Boost_nowide_SYSTEM_LIBS )
set(Boost_nowide_FRAMEWORK_DIRS )
set(Boost_nowide_FRAMEWORKS )
set(Boost_nowide_BUILD_MODULES_PATHS )
set(Boost_nowide_DEPENDENCIES Boost::filesystem Boost::_libboost)
set(Boost_nowide_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math VARIABLES #############################################

set(Boost_math_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_RES_DIRS )
set(Boost_math_DEFINITIONS )
set(Boost_math_COMPILE_DEFINITIONS )
set(Boost_math_COMPILE_OPTIONS_C "")
set(Boost_math_COMPILE_OPTIONS_CXX "")
set(Boost_math_LIBS )
set(Boost_math_SYSTEM_LIBS )
set(Boost_math_FRAMEWORK_DIRS )
set(Boost_math_FRAMEWORKS )
set(Boost_math_BUILD_MODULES_PATHS )
set(Boost_math_DEPENDENCIES Boost::_libboost)
set(Boost_math_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_tr1l VARIABLES #############################################

set(Boost_math_tr1l_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_tr1l_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_tr1l_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_tr1l_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_tr1l_RES_DIRS )
set(Boost_math_tr1l_DEFINITIONS )
set(Boost_math_tr1l_COMPILE_DEFINITIONS )
set(Boost_math_tr1l_COMPILE_OPTIONS_C "")
set(Boost_math_tr1l_COMPILE_OPTIONS_CXX "")
set(Boost_math_tr1l_LIBS boost_math_tr1l)
set(Boost_math_tr1l_SYSTEM_LIBS )
set(Boost_math_tr1l_FRAMEWORK_DIRS )
set(Boost_math_tr1l_FRAMEWORKS )
set(Boost_math_tr1l_BUILD_MODULES_PATHS )
set(Boost_math_tr1l_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_tr1l_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_tr1f VARIABLES #############################################

set(Boost_math_tr1f_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_tr1f_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_tr1f_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_tr1f_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_tr1f_RES_DIRS )
set(Boost_math_tr1f_DEFINITIONS )
set(Boost_math_tr1f_COMPILE_DEFINITIONS )
set(Boost_math_tr1f_COMPILE_OPTIONS_C "")
set(Boost_math_tr1f_COMPILE_OPTIONS_CXX "")
set(Boost_math_tr1f_LIBS boost_math_tr1f)
set(Boost_math_tr1f_SYSTEM_LIBS )
set(Boost_math_tr1f_FRAMEWORK_DIRS )
set(Boost_math_tr1f_FRAMEWORKS )
set(Boost_math_tr1f_BUILD_MODULES_PATHS )
set(Boost_math_tr1f_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_tr1f_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_tr1 VARIABLES #############################################

set(Boost_math_tr1_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_tr1_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_tr1_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_tr1_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_tr1_RES_DIRS )
set(Boost_math_tr1_DEFINITIONS )
set(Boost_math_tr1_COMPILE_DEFINITIONS )
set(Boost_math_tr1_COMPILE_OPTIONS_C "")
set(Boost_math_tr1_COMPILE_OPTIONS_CXX "")
set(Boost_math_tr1_LIBS boost_math_tr1)
set(Boost_math_tr1_SYSTEM_LIBS )
set(Boost_math_tr1_FRAMEWORK_DIRS )
set(Boost_math_tr1_FRAMEWORKS )
set(Boost_math_tr1_BUILD_MODULES_PATHS )
set(Boost_math_tr1_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_tr1_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_c99l VARIABLES #############################################

set(Boost_math_c99l_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_c99l_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_c99l_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_c99l_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_c99l_RES_DIRS )
set(Boost_math_c99l_DEFINITIONS )
set(Boost_math_c99l_COMPILE_DEFINITIONS )
set(Boost_math_c99l_COMPILE_OPTIONS_C "")
set(Boost_math_c99l_COMPILE_OPTIONS_CXX "")
set(Boost_math_c99l_LIBS boost_math_c99l)
set(Boost_math_c99l_SYSTEM_LIBS )
set(Boost_math_c99l_FRAMEWORK_DIRS )
set(Boost_math_c99l_FRAMEWORKS )
set(Boost_math_c99l_BUILD_MODULES_PATHS )
set(Boost_math_c99l_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_c99l_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_c99f VARIABLES #############################################

set(Boost_math_c99f_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_c99f_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_c99f_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_c99f_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_c99f_RES_DIRS )
set(Boost_math_c99f_DEFINITIONS )
set(Boost_math_c99f_COMPILE_DEFINITIONS )
set(Boost_math_c99f_COMPILE_OPTIONS_C "")
set(Boost_math_c99f_COMPILE_OPTIONS_CXX "")
set(Boost_math_c99f_LIBS boost_math_c99f)
set(Boost_math_c99f_SYSTEM_LIBS )
set(Boost_math_c99f_FRAMEWORK_DIRS )
set(Boost_math_c99f_FRAMEWORKS )
set(Boost_math_c99f_BUILD_MODULES_PATHS )
set(Boost_math_c99f_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_c99f_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT math_c99 VARIABLES #############################################

set(Boost_math_c99_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_math_c99_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_math_c99_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_math_c99_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_math_c99_RES_DIRS )
set(Boost_math_c99_DEFINITIONS )
set(Boost_math_c99_COMPILE_DEFINITIONS )
set(Boost_math_c99_COMPILE_OPTIONS_C "")
set(Boost_math_c99_COMPILE_OPTIONS_CXX "")
set(Boost_math_c99_LIBS boost_math_c99)
set(Boost_math_c99_SYSTEM_LIBS )
set(Boost_math_c99_FRAMEWORK_DIRS )
set(Boost_math_c99_FRAMEWORKS )
set(Boost_math_c99_BUILD_MODULES_PATHS )
set(Boost_math_c99_DEPENDENCIES Boost::math Boost::_libboost)
set(Boost_math_c99_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT log VARIABLES #############################################

set(Boost_log_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_log_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_log_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_log_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_log_RES_DIRS )
set(Boost_log_DEFINITIONS )
set(Boost_log_COMPILE_DEFINITIONS )
set(Boost_log_COMPILE_OPTIONS_C "")
set(Boost_log_COMPILE_OPTIONS_CXX "")
set(Boost_log_LIBS boost_log)
set(Boost_log_SYSTEM_LIBS )
set(Boost_log_FRAMEWORK_DIRS )
set(Boost_log_FRAMEWORKS )
set(Boost_log_BUILD_MODULES_PATHS )
set(Boost_log_DEPENDENCIES Boost::atomic Boost::container Boost::date_time Boost::exception Boost::filesystem Boost::random Boost::regex Boost::system Boost::thread Boost::_libboost)
set(Boost_log_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT log_setup VARIABLES #############################################

set(Boost_log_setup_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_log_setup_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_log_setup_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_log_setup_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_log_setup_RES_DIRS )
set(Boost_log_setup_DEFINITIONS )
set(Boost_log_setup_COMPILE_DEFINITIONS )
set(Boost_log_setup_COMPILE_OPTIONS_C "")
set(Boost_log_setup_COMPILE_OPTIONS_CXX "")
set(Boost_log_setup_LIBS boost_log_setup)
set(Boost_log_setup_SYSTEM_LIBS )
set(Boost_log_setup_FRAMEWORK_DIRS )
set(Boost_log_setup_FRAMEWORKS )
set(Boost_log_setup_BUILD_MODULES_PATHS )
set(Boost_log_setup_DEPENDENCIES Boost::log Boost::_libboost)
set(Boost_log_setup_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT locale VARIABLES #############################################

set(Boost_locale_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_locale_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_locale_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_locale_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_locale_RES_DIRS )
set(Boost_locale_DEFINITIONS )
set(Boost_locale_COMPILE_DEFINITIONS )
set(Boost_locale_COMPILE_OPTIONS_C "")
set(Boost_locale_COMPILE_OPTIONS_CXX "")
set(Boost_locale_LIBS boost_locale)
set(Boost_locale_SYSTEM_LIBS )
set(Boost_locale_FRAMEWORK_DIRS )
set(Boost_locale_FRAMEWORKS )
set(Boost_locale_BUILD_MODULES_PATHS )
set(Boost_locale_DEPENDENCIES Boost::thread Boost::_libboost)
set(Boost_locale_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT json VARIABLES #############################################

set(Boost_json_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_json_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_json_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_json_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_json_RES_DIRS )
set(Boost_json_DEFINITIONS )
set(Boost_json_COMPILE_DEFINITIONS )
set(Boost_json_COMPILE_OPTIONS_C "")
set(Boost_json_COMPILE_OPTIONS_CXX "")
set(Boost_json_LIBS boost_json)
set(Boost_json_SYSTEM_LIBS )
set(Boost_json_FRAMEWORK_DIRS )
set(Boost_json_FRAMEWORKS )
set(Boost_json_BUILD_MODULES_PATHS )
set(Boost_json_DEPENDENCIES Boost::container Boost::system Boost::_libboost)
set(Boost_json_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT iostreams VARIABLES #############################################

set(Boost_iostreams_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_iostreams_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_iostreams_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_iostreams_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_iostreams_RES_DIRS )
set(Boost_iostreams_DEFINITIONS )
set(Boost_iostreams_COMPILE_DEFINITIONS )
set(Boost_iostreams_COMPILE_OPTIONS_C "")
set(Boost_iostreams_COMPILE_OPTIONS_CXX "")
set(Boost_iostreams_LIBS boost_iostreams)
set(Boost_iostreams_SYSTEM_LIBS )
set(Boost_iostreams_FRAMEWORK_DIRS )
set(Boost_iostreams_FRAMEWORKS )
set(Boost_iostreams_BUILD_MODULES_PATHS )
set(Boost_iostreams_DEPENDENCIES Boost::random Boost::regex Boost::_libboost BZip2::BZip2 ZLIB::ZLIB)
set(Boost_iostreams_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT graph VARIABLES #############################################

set(Boost_graph_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_graph_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_graph_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_graph_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_graph_RES_DIRS )
set(Boost_graph_DEFINITIONS )
set(Boost_graph_COMPILE_DEFINITIONS )
set(Boost_graph_COMPILE_OPTIONS_C "")
set(Boost_graph_COMPILE_OPTIONS_CXX "")
set(Boost_graph_LIBS boost_graph)
set(Boost_graph_SYSTEM_LIBS )
set(Boost_graph_FRAMEWORK_DIRS )
set(Boost_graph_FRAMEWORKS )
set(Boost_graph_BUILD_MODULES_PATHS )
set(Boost_graph_DEPENDENCIES Boost::math Boost::random Boost::regex Boost::serialization Boost::_libboost)
set(Boost_graph_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT context VARIABLES #############################################

set(Boost_context_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_context_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_context_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_context_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_context_RES_DIRS )
set(Boost_context_DEFINITIONS )
set(Boost_context_COMPILE_DEFINITIONS )
set(Boost_context_COMPILE_OPTIONS_C "")
set(Boost_context_COMPILE_OPTIONS_CXX "")
set(Boost_context_LIBS boost_context)
set(Boost_context_SYSTEM_LIBS )
set(Boost_context_FRAMEWORK_DIRS )
set(Boost_context_FRAMEWORKS )
set(Boost_context_BUILD_MODULES_PATHS )
set(Boost_context_DEPENDENCIES Boost::_libboost)
set(Boost_context_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT fiber VARIABLES #############################################

set(Boost_fiber_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_fiber_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_fiber_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_fiber_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_fiber_RES_DIRS )
set(Boost_fiber_DEFINITIONS )
set(Boost_fiber_COMPILE_DEFINITIONS )
set(Boost_fiber_COMPILE_OPTIONS_C "")
set(Boost_fiber_COMPILE_OPTIONS_CXX "")
set(Boost_fiber_LIBS boost_fiber)
set(Boost_fiber_SYSTEM_LIBS )
set(Boost_fiber_FRAMEWORK_DIRS )
set(Boost_fiber_FRAMEWORKS )
set(Boost_fiber_BUILD_MODULES_PATHS )
set(Boost_fiber_DEPENDENCIES Boost::context Boost::filesystem Boost::_libboost)
set(Boost_fiber_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT fiber_numa VARIABLES #############################################

set(Boost_fiber_numa_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_fiber_numa_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_fiber_numa_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_fiber_numa_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_fiber_numa_RES_DIRS )
set(Boost_fiber_numa_DEFINITIONS )
set(Boost_fiber_numa_COMPILE_DEFINITIONS )
set(Boost_fiber_numa_COMPILE_OPTIONS_C "")
set(Boost_fiber_numa_COMPILE_OPTIONS_CXX "")
set(Boost_fiber_numa_LIBS boost_fiber_numa)
set(Boost_fiber_numa_SYSTEM_LIBS )
set(Boost_fiber_numa_FRAMEWORK_DIRS )
set(Boost_fiber_numa_FRAMEWORKS )
set(Boost_fiber_numa_BUILD_MODULES_PATHS )
set(Boost_fiber_numa_DEPENDENCIES Boost::fiber Boost::_libboost)
set(Boost_fiber_numa_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT coroutine VARIABLES #############################################

set(Boost_coroutine_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_coroutine_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_coroutine_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_coroutine_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_coroutine_RES_DIRS )
set(Boost_coroutine_DEFINITIONS )
set(Boost_coroutine_COMPILE_DEFINITIONS )
set(Boost_coroutine_COMPILE_OPTIONS_C "")
set(Boost_coroutine_COMPILE_OPTIONS_CXX "")
set(Boost_coroutine_LIBS boost_coroutine)
set(Boost_coroutine_SYSTEM_LIBS )
set(Boost_coroutine_FRAMEWORK_DIRS )
set(Boost_coroutine_FRAMEWORKS )
set(Boost_coroutine_BUILD_MODULES_PATHS )
set(Boost_coroutine_DEPENDENCIES Boost::context Boost::exception Boost::system Boost::_libboost)
set(Boost_coroutine_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT contract VARIABLES #############################################

set(Boost_contract_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_contract_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_contract_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_contract_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_contract_RES_DIRS )
set(Boost_contract_DEFINITIONS )
set(Boost_contract_COMPILE_DEFINITIONS )
set(Boost_contract_COMPILE_OPTIONS_C "")
set(Boost_contract_COMPILE_OPTIONS_CXX "")
set(Boost_contract_LIBS boost_contract)
set(Boost_contract_SYSTEM_LIBS )
set(Boost_contract_FRAMEWORK_DIRS )
set(Boost_contract_FRAMEWORKS )
set(Boost_contract_BUILD_MODULES_PATHS )
set(Boost_contract_DEPENDENCIES Boost::exception Boost::thread Boost::_libboost)
set(Boost_contract_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT boost VARIABLES #############################################

set(Boost_boost_INCLUDE_DIRS "C:/.conan/67e52c/1/include")
set(Boost_boost_INCLUDE_DIR "C:/.conan/67e52c/1/include")
set(Boost_boost_INCLUDES "C:/.conan/67e52c/1/include")
set(Boost_boost_LIB_DIRS "C:/.conan/67e52c/1/lib")
set(Boost_boost_RES_DIRS )
set(Boost_boost_DEFINITIONS )
set(Boost_boost_COMPILE_DEFINITIONS )
set(Boost_boost_COMPILE_OPTIONS_C "")
set(Boost_boost_COMPILE_OPTIONS_CXX "")
set(Boost_boost_LIBS )
set(Boost_boost_SYSTEM_LIBS )
set(Boost_boost_FRAMEWORK_DIRS )
set(Boost_boost_FRAMEWORKS )
set(Boost_boost_BUILD_MODULES_PATHS )
set(Boost_boost_DEPENDENCIES Boost::headers)
set(Boost_boost_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)


########## FIND PACKAGE DEPENDENCY ##########################################################
#############################################################################################

include(CMakeFindDependencyMacro)

if(NOT BZip2_FOUND)
    find_dependency(BZip2 REQUIRED)
else()
    conan_message(STATUS "Conan: Dependency BZip2 already found")
endif()

if(NOT ZLIB_FOUND)
    find_dependency(ZLIB REQUIRED)
else()
    conan_message(STATUS "Conan: Dependency ZLIB already found")
endif()


########## FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #######################################
#############################################################################################

########## COMPONENT dynamic_linking FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_dynamic_linking_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_dynamic_linking_FRAMEWORKS_FOUND "${Boost_dynamic_linking_FRAMEWORKS}" "${Boost_dynamic_linking_FRAMEWORK_DIRS}")

set(Boost_dynamic_linking_LIB_TARGETS "")
set(Boost_dynamic_linking_NOT_USED "")
set(Boost_dynamic_linking_LIBS_FRAMEWORKS_DEPS ${Boost_dynamic_linking_FRAMEWORKS_FOUND} ${Boost_dynamic_linking_SYSTEM_LIBS} ${Boost_dynamic_linking_DEPENDENCIES})
conan_package_library_targets("${Boost_dynamic_linking_LIBS}"
                              "${Boost_dynamic_linking_LIB_DIRS}"
                              "${Boost_dynamic_linking_LIBS_FRAMEWORKS_DEPS}"
                              Boost_dynamic_linking_NOT_USED
                              Boost_dynamic_linking_LIB_TARGETS
                              ""
                              "Boost_dynamic_linking")

set(Boost_dynamic_linking_LINK_LIBS ${Boost_dynamic_linking_LIB_TARGETS} ${Boost_dynamic_linking_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT disable_autolinking FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_disable_autolinking_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_disable_autolinking_FRAMEWORKS_FOUND "${Boost_disable_autolinking_FRAMEWORKS}" "${Boost_disable_autolinking_FRAMEWORK_DIRS}")

set(Boost_disable_autolinking_LIB_TARGETS "")
set(Boost_disable_autolinking_NOT_USED "")
set(Boost_disable_autolinking_LIBS_FRAMEWORKS_DEPS ${Boost_disable_autolinking_FRAMEWORKS_FOUND} ${Boost_disable_autolinking_SYSTEM_LIBS} ${Boost_disable_autolinking_DEPENDENCIES})
conan_package_library_targets("${Boost_disable_autolinking_LIBS}"
                              "${Boost_disable_autolinking_LIB_DIRS}"
                              "${Boost_disable_autolinking_LIBS_FRAMEWORKS_DEPS}"
                              Boost_disable_autolinking_NOT_USED
                              Boost_disable_autolinking_LIB_TARGETS
                              ""
                              "Boost_disable_autolinking")

set(Boost_disable_autolinking_LINK_LIBS ${Boost_disable_autolinking_LIB_TARGETS} ${Boost_disable_autolinking_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT diagnostic_definitions FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_diagnostic_definitions_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_diagnostic_definitions_FRAMEWORKS_FOUND "${Boost_diagnostic_definitions_FRAMEWORKS}" "${Boost_diagnostic_definitions_FRAMEWORK_DIRS}")

set(Boost_diagnostic_definitions_LIB_TARGETS "")
set(Boost_diagnostic_definitions_NOT_USED "")
set(Boost_diagnostic_definitions_LIBS_FRAMEWORKS_DEPS ${Boost_diagnostic_definitions_FRAMEWORKS_FOUND} ${Boost_diagnostic_definitions_SYSTEM_LIBS} ${Boost_diagnostic_definitions_DEPENDENCIES})
conan_package_library_targets("${Boost_diagnostic_definitions_LIBS}"
                              "${Boost_diagnostic_definitions_LIB_DIRS}"
                              "${Boost_diagnostic_definitions_LIBS_FRAMEWORKS_DEPS}"
                              Boost_diagnostic_definitions_NOT_USED
                              Boost_diagnostic_definitions_LIB_TARGETS
                              ""
                              "Boost_diagnostic_definitions")

set(Boost_diagnostic_definitions_LINK_LIBS ${Boost_diagnostic_definitions_LIB_TARGETS} ${Boost_diagnostic_definitions_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT headers FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_headers_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_headers_FRAMEWORKS_FOUND "${Boost_headers_FRAMEWORKS}" "${Boost_headers_FRAMEWORK_DIRS}")

set(Boost_headers_LIB_TARGETS "")
set(Boost_headers_NOT_USED "")
set(Boost_headers_LIBS_FRAMEWORKS_DEPS ${Boost_headers_FRAMEWORKS_FOUND} ${Boost_headers_SYSTEM_LIBS} ${Boost_headers_DEPENDENCIES})
conan_package_library_targets("${Boost_headers_LIBS}"
                              "${Boost_headers_LIB_DIRS}"
                              "${Boost_headers_LIBS_FRAMEWORKS_DEPS}"
                              Boost_headers_NOT_USED
                              Boost_headers_LIB_TARGETS
                              ""
                              "Boost_headers")

set(Boost_headers_LINK_LIBS ${Boost_headers_LIB_TARGETS} ${Boost_headers_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT _libboost FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost__libboost_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost__libboost_FRAMEWORKS_FOUND "${Boost__libboost_FRAMEWORKS}" "${Boost__libboost_FRAMEWORK_DIRS}")

set(Boost__libboost_LIB_TARGETS "")
set(Boost__libboost_NOT_USED "")
set(Boost__libboost_LIBS_FRAMEWORKS_DEPS ${Boost__libboost_FRAMEWORKS_FOUND} ${Boost__libboost_SYSTEM_LIBS} ${Boost__libboost_DEPENDENCIES})
conan_package_library_targets("${Boost__libboost_LIBS}"
                              "${Boost__libboost_LIB_DIRS}"
                              "${Boost__libboost_LIBS_FRAMEWORKS_DEPS}"
                              Boost__libboost_NOT_USED
                              Boost__libboost_LIB_TARGETS
                              ""
                              "Boost__libboost")

set(Boost__libboost_LINK_LIBS ${Boost__libboost_LIB_TARGETS} ${Boost__libboost_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT serialization FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_serialization_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_serialization_FRAMEWORKS_FOUND "${Boost_serialization_FRAMEWORKS}" "${Boost_serialization_FRAMEWORK_DIRS}")

set(Boost_serialization_LIB_TARGETS "")
set(Boost_serialization_NOT_USED "")
set(Boost_serialization_LIBS_FRAMEWORKS_DEPS ${Boost_serialization_FRAMEWORKS_FOUND} ${Boost_serialization_SYSTEM_LIBS} ${Boost_serialization_DEPENDENCIES})
conan_package_library_targets("${Boost_serialization_LIBS}"
                              "${Boost_serialization_LIB_DIRS}"
                              "${Boost_serialization_LIBS_FRAMEWORKS_DEPS}"
                              Boost_serialization_NOT_USED
                              Boost_serialization_LIB_TARGETS
                              ""
                              "Boost_serialization")

set(Boost_serialization_LINK_LIBS ${Boost_serialization_LIB_TARGETS} ${Boost_serialization_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT wserialization FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_wserialization_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_wserialization_FRAMEWORKS_FOUND "${Boost_wserialization_FRAMEWORKS}" "${Boost_wserialization_FRAMEWORK_DIRS}")

set(Boost_wserialization_LIB_TARGETS "")
set(Boost_wserialization_NOT_USED "")
set(Boost_wserialization_LIBS_FRAMEWORKS_DEPS ${Boost_wserialization_FRAMEWORKS_FOUND} ${Boost_wserialization_SYSTEM_LIBS} ${Boost_wserialization_DEPENDENCIES})
conan_package_library_targets("${Boost_wserialization_LIBS}"
                              "${Boost_wserialization_LIB_DIRS}"
                              "${Boost_wserialization_LIBS_FRAMEWORKS_DEPS}"
                              Boost_wserialization_NOT_USED
                              Boost_wserialization_LIB_TARGETS
                              ""
                              "Boost_wserialization")

set(Boost_wserialization_LINK_LIBS ${Boost_wserialization_LIB_TARGETS} ${Boost_wserialization_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT system FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_system_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_system_FRAMEWORKS_FOUND "${Boost_system_FRAMEWORKS}" "${Boost_system_FRAMEWORK_DIRS}")

set(Boost_system_LIB_TARGETS "")
set(Boost_system_NOT_USED "")
set(Boost_system_LIBS_FRAMEWORKS_DEPS ${Boost_system_FRAMEWORKS_FOUND} ${Boost_system_SYSTEM_LIBS} ${Boost_system_DEPENDENCIES})
conan_package_library_targets("${Boost_system_LIBS}"
                              "${Boost_system_LIB_DIRS}"
                              "${Boost_system_LIBS_FRAMEWORKS_DEPS}"
                              Boost_system_NOT_USED
                              Boost_system_LIB_TARGETS
                              ""
                              "Boost_system")

set(Boost_system_LINK_LIBS ${Boost_system_LIB_TARGETS} ${Boost_system_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT atomic FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_atomic_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_atomic_FRAMEWORKS_FOUND "${Boost_atomic_FRAMEWORKS}" "${Boost_atomic_FRAMEWORK_DIRS}")

set(Boost_atomic_LIB_TARGETS "")
set(Boost_atomic_NOT_USED "")
set(Boost_atomic_LIBS_FRAMEWORKS_DEPS ${Boost_atomic_FRAMEWORKS_FOUND} ${Boost_atomic_SYSTEM_LIBS} ${Boost_atomic_DEPENDENCIES})
conan_package_library_targets("${Boost_atomic_LIBS}"
                              "${Boost_atomic_LIB_DIRS}"
                              "${Boost_atomic_LIBS_FRAMEWORKS_DEPS}"
                              Boost_atomic_NOT_USED
                              Boost_atomic_LIB_TARGETS
                              ""
                              "Boost_atomic")

set(Boost_atomic_LINK_LIBS ${Boost_atomic_LIB_TARGETS} ${Boost_atomic_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT filesystem FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_filesystem_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_filesystem_FRAMEWORKS_FOUND "${Boost_filesystem_FRAMEWORKS}" "${Boost_filesystem_FRAMEWORK_DIRS}")

set(Boost_filesystem_LIB_TARGETS "")
set(Boost_filesystem_NOT_USED "")
set(Boost_filesystem_LIBS_FRAMEWORKS_DEPS ${Boost_filesystem_FRAMEWORKS_FOUND} ${Boost_filesystem_SYSTEM_LIBS} ${Boost_filesystem_DEPENDENCIES})
conan_package_library_targets("${Boost_filesystem_LIBS}"
                              "${Boost_filesystem_LIB_DIRS}"
                              "${Boost_filesystem_LIBS_FRAMEWORKS_DEPS}"
                              Boost_filesystem_NOT_USED
                              Boost_filesystem_LIB_TARGETS
                              ""
                              "Boost_filesystem")

set(Boost_filesystem_LINK_LIBS ${Boost_filesystem_LIB_TARGETS} ${Boost_filesystem_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT wave FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_wave_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_wave_FRAMEWORKS_FOUND "${Boost_wave_FRAMEWORKS}" "${Boost_wave_FRAMEWORK_DIRS}")

set(Boost_wave_LIB_TARGETS "")
set(Boost_wave_NOT_USED "")
set(Boost_wave_LIBS_FRAMEWORKS_DEPS ${Boost_wave_FRAMEWORKS_FOUND} ${Boost_wave_SYSTEM_LIBS} ${Boost_wave_DEPENDENCIES})
conan_package_library_targets("${Boost_wave_LIBS}"
                              "${Boost_wave_LIB_DIRS}"
                              "${Boost_wave_LIBS_FRAMEWORKS_DEPS}"
                              Boost_wave_NOT_USED
                              Boost_wave_LIB_TARGETS
                              ""
                              "Boost_wave")

set(Boost_wave_LINK_LIBS ${Boost_wave_LIB_TARGETS} ${Boost_wave_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT exception FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_exception_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_exception_FRAMEWORKS_FOUND "${Boost_exception_FRAMEWORKS}" "${Boost_exception_FRAMEWORK_DIRS}")

set(Boost_exception_LIB_TARGETS "")
set(Boost_exception_NOT_USED "")
set(Boost_exception_LIBS_FRAMEWORKS_DEPS ${Boost_exception_FRAMEWORKS_FOUND} ${Boost_exception_SYSTEM_LIBS} ${Boost_exception_DEPENDENCIES})
conan_package_library_targets("${Boost_exception_LIBS}"
                              "${Boost_exception_LIB_DIRS}"
                              "${Boost_exception_LIBS_FRAMEWORKS_DEPS}"
                              Boost_exception_NOT_USED
                              Boost_exception_LIB_TARGETS
                              ""
                              "Boost_exception")

set(Boost_exception_LINK_LIBS ${Boost_exception_LIB_TARGETS} ${Boost_exception_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT test FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_test_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_test_FRAMEWORKS_FOUND "${Boost_test_FRAMEWORKS}" "${Boost_test_FRAMEWORK_DIRS}")

set(Boost_test_LIB_TARGETS "")
set(Boost_test_NOT_USED "")
set(Boost_test_LIBS_FRAMEWORKS_DEPS ${Boost_test_FRAMEWORKS_FOUND} ${Boost_test_SYSTEM_LIBS} ${Boost_test_DEPENDENCIES})
conan_package_library_targets("${Boost_test_LIBS}"
                              "${Boost_test_LIB_DIRS}"
                              "${Boost_test_LIBS_FRAMEWORKS_DEPS}"
                              Boost_test_NOT_USED
                              Boost_test_LIB_TARGETS
                              ""
                              "Boost_test")

set(Boost_test_LINK_LIBS ${Boost_test_LIB_TARGETS} ${Boost_test_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT test_exec_monitor FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_test_exec_monitor_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_test_exec_monitor_FRAMEWORKS_FOUND "${Boost_test_exec_monitor_FRAMEWORKS}" "${Boost_test_exec_monitor_FRAMEWORK_DIRS}")

set(Boost_test_exec_monitor_LIB_TARGETS "")
set(Boost_test_exec_monitor_NOT_USED "")
set(Boost_test_exec_monitor_LIBS_FRAMEWORKS_DEPS ${Boost_test_exec_monitor_FRAMEWORKS_FOUND} ${Boost_test_exec_monitor_SYSTEM_LIBS} ${Boost_test_exec_monitor_DEPENDENCIES})
conan_package_library_targets("${Boost_test_exec_monitor_LIBS}"
                              "${Boost_test_exec_monitor_LIB_DIRS}"
                              "${Boost_test_exec_monitor_LIBS_FRAMEWORKS_DEPS}"
                              Boost_test_exec_monitor_NOT_USED
                              Boost_test_exec_monitor_LIB_TARGETS
                              ""
                              "Boost_test_exec_monitor")

set(Boost_test_exec_monitor_LINK_LIBS ${Boost_test_exec_monitor_LIB_TARGETS} ${Boost_test_exec_monitor_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT prg_exec_monitor FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_prg_exec_monitor_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_prg_exec_monitor_FRAMEWORKS_FOUND "${Boost_prg_exec_monitor_FRAMEWORKS}" "${Boost_prg_exec_monitor_FRAMEWORK_DIRS}")

set(Boost_prg_exec_monitor_LIB_TARGETS "")
set(Boost_prg_exec_monitor_NOT_USED "")
set(Boost_prg_exec_monitor_LIBS_FRAMEWORKS_DEPS ${Boost_prg_exec_monitor_FRAMEWORKS_FOUND} ${Boost_prg_exec_monitor_SYSTEM_LIBS} ${Boost_prg_exec_monitor_DEPENDENCIES})
conan_package_library_targets("${Boost_prg_exec_monitor_LIBS}"
                              "${Boost_prg_exec_monitor_LIB_DIRS}"
                              "${Boost_prg_exec_monitor_LIBS_FRAMEWORKS_DEPS}"
                              Boost_prg_exec_monitor_NOT_USED
                              Boost_prg_exec_monitor_LIB_TARGETS
                              ""
                              "Boost_prg_exec_monitor")

set(Boost_prg_exec_monitor_LINK_LIBS ${Boost_prg_exec_monitor_LIB_TARGETS} ${Boost_prg_exec_monitor_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT unit_test_framework FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_unit_test_framework_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_unit_test_framework_FRAMEWORKS_FOUND "${Boost_unit_test_framework_FRAMEWORKS}" "${Boost_unit_test_framework_FRAMEWORK_DIRS}")

set(Boost_unit_test_framework_LIB_TARGETS "")
set(Boost_unit_test_framework_NOT_USED "")
set(Boost_unit_test_framework_LIBS_FRAMEWORKS_DEPS ${Boost_unit_test_framework_FRAMEWORKS_FOUND} ${Boost_unit_test_framework_SYSTEM_LIBS} ${Boost_unit_test_framework_DEPENDENCIES})
conan_package_library_targets("${Boost_unit_test_framework_LIBS}"
                              "${Boost_unit_test_framework_LIB_DIRS}"
                              "${Boost_unit_test_framework_LIBS_FRAMEWORKS_DEPS}"
                              Boost_unit_test_framework_NOT_USED
                              Boost_unit_test_framework_LIB_TARGETS
                              ""
                              "Boost_unit_test_framework")

set(Boost_unit_test_framework_LINK_LIBS ${Boost_unit_test_framework_LIB_TARGETS} ${Boost_unit_test_framework_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT date_time FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_date_time_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_date_time_FRAMEWORKS_FOUND "${Boost_date_time_FRAMEWORKS}" "${Boost_date_time_FRAMEWORK_DIRS}")

set(Boost_date_time_LIB_TARGETS "")
set(Boost_date_time_NOT_USED "")
set(Boost_date_time_LIBS_FRAMEWORKS_DEPS ${Boost_date_time_FRAMEWORKS_FOUND} ${Boost_date_time_SYSTEM_LIBS} ${Boost_date_time_DEPENDENCIES})
conan_package_library_targets("${Boost_date_time_LIBS}"
                              "${Boost_date_time_LIB_DIRS}"
                              "${Boost_date_time_LIBS_FRAMEWORKS_DEPS}"
                              Boost_date_time_NOT_USED
                              Boost_date_time_LIB_TARGETS
                              ""
                              "Boost_date_time")

set(Boost_date_time_LINK_LIBS ${Boost_date_time_LIB_TARGETS} ${Boost_date_time_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT container FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_container_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_container_FRAMEWORKS_FOUND "${Boost_container_FRAMEWORKS}" "${Boost_container_FRAMEWORK_DIRS}")

set(Boost_container_LIB_TARGETS "")
set(Boost_container_NOT_USED "")
set(Boost_container_LIBS_FRAMEWORKS_DEPS ${Boost_container_FRAMEWORKS_FOUND} ${Boost_container_SYSTEM_LIBS} ${Boost_container_DEPENDENCIES})
conan_package_library_targets("${Boost_container_LIBS}"
                              "${Boost_container_LIB_DIRS}"
                              "${Boost_container_LIBS_FRAMEWORKS_DEPS}"
                              Boost_container_NOT_USED
                              Boost_container_LIB_TARGETS
                              ""
                              "Boost_container")

set(Boost_container_LINK_LIBS ${Boost_container_LIB_TARGETS} ${Boost_container_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT chrono FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_chrono_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_chrono_FRAMEWORKS_FOUND "${Boost_chrono_FRAMEWORKS}" "${Boost_chrono_FRAMEWORK_DIRS}")

set(Boost_chrono_LIB_TARGETS "")
set(Boost_chrono_NOT_USED "")
set(Boost_chrono_LIBS_FRAMEWORKS_DEPS ${Boost_chrono_FRAMEWORKS_FOUND} ${Boost_chrono_SYSTEM_LIBS} ${Boost_chrono_DEPENDENCIES})
conan_package_library_targets("${Boost_chrono_LIBS}"
                              "${Boost_chrono_LIB_DIRS}"
                              "${Boost_chrono_LIBS_FRAMEWORKS_DEPS}"
                              Boost_chrono_NOT_USED
                              Boost_chrono_LIB_TARGETS
                              ""
                              "Boost_chrono")

set(Boost_chrono_LINK_LIBS ${Boost_chrono_LIB_TARGETS} ${Boost_chrono_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT thread FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_thread_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_thread_FRAMEWORKS_FOUND "${Boost_thread_FRAMEWORKS}" "${Boost_thread_FRAMEWORK_DIRS}")

set(Boost_thread_LIB_TARGETS "")
set(Boost_thread_NOT_USED "")
set(Boost_thread_LIBS_FRAMEWORKS_DEPS ${Boost_thread_FRAMEWORKS_FOUND} ${Boost_thread_SYSTEM_LIBS} ${Boost_thread_DEPENDENCIES})
conan_package_library_targets("${Boost_thread_LIBS}"
                              "${Boost_thread_LIB_DIRS}"
                              "${Boost_thread_LIBS_FRAMEWORKS_DEPS}"
                              Boost_thread_NOT_USED
                              Boost_thread_LIB_TARGETS
                              ""
                              "Boost_thread")

set(Boost_thread_LINK_LIBS ${Boost_thread_LIB_TARGETS} ${Boost_thread_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT type_erasure FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_type_erasure_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_type_erasure_FRAMEWORKS_FOUND "${Boost_type_erasure_FRAMEWORKS}" "${Boost_type_erasure_FRAMEWORK_DIRS}")

set(Boost_type_erasure_LIB_TARGETS "")
set(Boost_type_erasure_NOT_USED "")
set(Boost_type_erasure_LIBS_FRAMEWORKS_DEPS ${Boost_type_erasure_FRAMEWORKS_FOUND} ${Boost_type_erasure_SYSTEM_LIBS} ${Boost_type_erasure_DEPENDENCIES})
conan_package_library_targets("${Boost_type_erasure_LIBS}"
                              "${Boost_type_erasure_LIB_DIRS}"
                              "${Boost_type_erasure_LIBS_FRAMEWORKS_DEPS}"
                              Boost_type_erasure_NOT_USED
                              Boost_type_erasure_LIB_TARGETS
                              ""
                              "Boost_type_erasure")

set(Boost_type_erasure_LINK_LIBS ${Boost_type_erasure_LIB_TARGETS} ${Boost_type_erasure_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT timer FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_timer_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_timer_FRAMEWORKS_FOUND "${Boost_timer_FRAMEWORKS}" "${Boost_timer_FRAMEWORK_DIRS}")

set(Boost_timer_LIB_TARGETS "")
set(Boost_timer_NOT_USED "")
set(Boost_timer_LIBS_FRAMEWORKS_DEPS ${Boost_timer_FRAMEWORKS_FOUND} ${Boost_timer_SYSTEM_LIBS} ${Boost_timer_DEPENDENCIES})
conan_package_library_targets("${Boost_timer_LIBS}"
                              "${Boost_timer_LIB_DIRS}"
                              "${Boost_timer_LIBS_FRAMEWORKS_DEPS}"
                              Boost_timer_NOT_USED
                              Boost_timer_LIB_TARGETS
                              ""
                              "Boost_timer")

set(Boost_timer_LINK_LIBS ${Boost_timer_LIB_TARGETS} ${Boost_timer_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT stacktrace FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_stacktrace_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_stacktrace_FRAMEWORKS_FOUND "${Boost_stacktrace_FRAMEWORKS}" "${Boost_stacktrace_FRAMEWORK_DIRS}")

set(Boost_stacktrace_LIB_TARGETS "")
set(Boost_stacktrace_NOT_USED "")
set(Boost_stacktrace_LIBS_FRAMEWORKS_DEPS ${Boost_stacktrace_FRAMEWORKS_FOUND} ${Boost_stacktrace_SYSTEM_LIBS} ${Boost_stacktrace_DEPENDENCIES})
conan_package_library_targets("${Boost_stacktrace_LIBS}"
                              "${Boost_stacktrace_LIB_DIRS}"
                              "${Boost_stacktrace_LIBS_FRAMEWORKS_DEPS}"
                              Boost_stacktrace_NOT_USED
                              Boost_stacktrace_LIB_TARGETS
                              ""
                              "Boost_stacktrace")

set(Boost_stacktrace_LINK_LIBS ${Boost_stacktrace_LIB_TARGETS} ${Boost_stacktrace_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT stacktrace_windbg_cached FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_stacktrace_windbg_cached_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_stacktrace_windbg_cached_FRAMEWORKS_FOUND "${Boost_stacktrace_windbg_cached_FRAMEWORKS}" "${Boost_stacktrace_windbg_cached_FRAMEWORK_DIRS}")

set(Boost_stacktrace_windbg_cached_LIB_TARGETS "")
set(Boost_stacktrace_windbg_cached_NOT_USED "")
set(Boost_stacktrace_windbg_cached_LIBS_FRAMEWORKS_DEPS ${Boost_stacktrace_windbg_cached_FRAMEWORKS_FOUND} ${Boost_stacktrace_windbg_cached_SYSTEM_LIBS} ${Boost_stacktrace_windbg_cached_DEPENDENCIES})
conan_package_library_targets("${Boost_stacktrace_windbg_cached_LIBS}"
                              "${Boost_stacktrace_windbg_cached_LIB_DIRS}"
                              "${Boost_stacktrace_windbg_cached_LIBS_FRAMEWORKS_DEPS}"
                              Boost_stacktrace_windbg_cached_NOT_USED
                              Boost_stacktrace_windbg_cached_LIB_TARGETS
                              ""
                              "Boost_stacktrace_windbg_cached")

set(Boost_stacktrace_windbg_cached_LINK_LIBS ${Boost_stacktrace_windbg_cached_LIB_TARGETS} ${Boost_stacktrace_windbg_cached_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT stacktrace_windbg FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_stacktrace_windbg_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_stacktrace_windbg_FRAMEWORKS_FOUND "${Boost_stacktrace_windbg_FRAMEWORKS}" "${Boost_stacktrace_windbg_FRAMEWORK_DIRS}")

set(Boost_stacktrace_windbg_LIB_TARGETS "")
set(Boost_stacktrace_windbg_NOT_USED "")
set(Boost_stacktrace_windbg_LIBS_FRAMEWORKS_DEPS ${Boost_stacktrace_windbg_FRAMEWORKS_FOUND} ${Boost_stacktrace_windbg_SYSTEM_LIBS} ${Boost_stacktrace_windbg_DEPENDENCIES})
conan_package_library_targets("${Boost_stacktrace_windbg_LIBS}"
                              "${Boost_stacktrace_windbg_LIB_DIRS}"
                              "${Boost_stacktrace_windbg_LIBS_FRAMEWORKS_DEPS}"
                              Boost_stacktrace_windbg_NOT_USED
                              Boost_stacktrace_windbg_LIB_TARGETS
                              ""
                              "Boost_stacktrace_windbg")

set(Boost_stacktrace_windbg_LINK_LIBS ${Boost_stacktrace_windbg_LIB_TARGETS} ${Boost_stacktrace_windbg_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT stacktrace_noop FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_stacktrace_noop_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_stacktrace_noop_FRAMEWORKS_FOUND "${Boost_stacktrace_noop_FRAMEWORKS}" "${Boost_stacktrace_noop_FRAMEWORK_DIRS}")

set(Boost_stacktrace_noop_LIB_TARGETS "")
set(Boost_stacktrace_noop_NOT_USED "")
set(Boost_stacktrace_noop_LIBS_FRAMEWORKS_DEPS ${Boost_stacktrace_noop_FRAMEWORKS_FOUND} ${Boost_stacktrace_noop_SYSTEM_LIBS} ${Boost_stacktrace_noop_DEPENDENCIES})
conan_package_library_targets("${Boost_stacktrace_noop_LIBS}"
                              "${Boost_stacktrace_noop_LIB_DIRS}"
                              "${Boost_stacktrace_noop_LIBS_FRAMEWORKS_DEPS}"
                              Boost_stacktrace_noop_NOT_USED
                              Boost_stacktrace_noop_LIB_TARGETS
                              ""
                              "Boost_stacktrace_noop")

set(Boost_stacktrace_noop_LINK_LIBS ${Boost_stacktrace_noop_LIB_TARGETS} ${Boost_stacktrace_noop_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT regex FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_regex_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_regex_FRAMEWORKS_FOUND "${Boost_regex_FRAMEWORKS}" "${Boost_regex_FRAMEWORK_DIRS}")

set(Boost_regex_LIB_TARGETS "")
set(Boost_regex_NOT_USED "")
set(Boost_regex_LIBS_FRAMEWORKS_DEPS ${Boost_regex_FRAMEWORKS_FOUND} ${Boost_regex_SYSTEM_LIBS} ${Boost_regex_DEPENDENCIES})
conan_package_library_targets("${Boost_regex_LIBS}"
                              "${Boost_regex_LIB_DIRS}"
                              "${Boost_regex_LIBS_FRAMEWORKS_DEPS}"
                              Boost_regex_NOT_USED
                              Boost_regex_LIB_TARGETS
                              ""
                              "Boost_regex")

set(Boost_regex_LINK_LIBS ${Boost_regex_LIB_TARGETS} ${Boost_regex_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT random FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_random_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_random_FRAMEWORKS_FOUND "${Boost_random_FRAMEWORKS}" "${Boost_random_FRAMEWORK_DIRS}")

set(Boost_random_LIB_TARGETS "")
set(Boost_random_NOT_USED "")
set(Boost_random_LIBS_FRAMEWORKS_DEPS ${Boost_random_FRAMEWORKS_FOUND} ${Boost_random_SYSTEM_LIBS} ${Boost_random_DEPENDENCIES})
conan_package_library_targets("${Boost_random_LIBS}"
                              "${Boost_random_LIB_DIRS}"
                              "${Boost_random_LIBS_FRAMEWORKS_DEPS}"
                              Boost_random_NOT_USED
                              Boost_random_LIB_TARGETS
                              ""
                              "Boost_random")

set(Boost_random_LINK_LIBS ${Boost_random_LIB_TARGETS} ${Boost_random_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT program_options FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_program_options_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_program_options_FRAMEWORKS_FOUND "${Boost_program_options_FRAMEWORKS}" "${Boost_program_options_FRAMEWORK_DIRS}")

set(Boost_program_options_LIB_TARGETS "")
set(Boost_program_options_NOT_USED "")
set(Boost_program_options_LIBS_FRAMEWORKS_DEPS ${Boost_program_options_FRAMEWORKS_FOUND} ${Boost_program_options_SYSTEM_LIBS} ${Boost_program_options_DEPENDENCIES})
conan_package_library_targets("${Boost_program_options_LIBS}"
                              "${Boost_program_options_LIB_DIRS}"
                              "${Boost_program_options_LIBS_FRAMEWORKS_DEPS}"
                              Boost_program_options_NOT_USED
                              Boost_program_options_LIB_TARGETS
                              ""
                              "Boost_program_options")

set(Boost_program_options_LINK_LIBS ${Boost_program_options_LIB_TARGETS} ${Boost_program_options_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT nowide FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_nowide_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_nowide_FRAMEWORKS_FOUND "${Boost_nowide_FRAMEWORKS}" "${Boost_nowide_FRAMEWORK_DIRS}")

set(Boost_nowide_LIB_TARGETS "")
set(Boost_nowide_NOT_USED "")
set(Boost_nowide_LIBS_FRAMEWORKS_DEPS ${Boost_nowide_FRAMEWORKS_FOUND} ${Boost_nowide_SYSTEM_LIBS} ${Boost_nowide_DEPENDENCIES})
conan_package_library_targets("${Boost_nowide_LIBS}"
                              "${Boost_nowide_LIB_DIRS}"
                              "${Boost_nowide_LIBS_FRAMEWORKS_DEPS}"
                              Boost_nowide_NOT_USED
                              Boost_nowide_LIB_TARGETS
                              ""
                              "Boost_nowide")

set(Boost_nowide_LINK_LIBS ${Boost_nowide_LIB_TARGETS} ${Boost_nowide_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_FRAMEWORKS_FOUND "${Boost_math_FRAMEWORKS}" "${Boost_math_FRAMEWORK_DIRS}")

set(Boost_math_LIB_TARGETS "")
set(Boost_math_NOT_USED "")
set(Boost_math_LIBS_FRAMEWORKS_DEPS ${Boost_math_FRAMEWORKS_FOUND} ${Boost_math_SYSTEM_LIBS} ${Boost_math_DEPENDENCIES})
conan_package_library_targets("${Boost_math_LIBS}"
                              "${Boost_math_LIB_DIRS}"
                              "${Boost_math_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_NOT_USED
                              Boost_math_LIB_TARGETS
                              ""
                              "Boost_math")

set(Boost_math_LINK_LIBS ${Boost_math_LIB_TARGETS} ${Boost_math_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_tr1l FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_tr1l_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_tr1l_FRAMEWORKS_FOUND "${Boost_math_tr1l_FRAMEWORKS}" "${Boost_math_tr1l_FRAMEWORK_DIRS}")

set(Boost_math_tr1l_LIB_TARGETS "")
set(Boost_math_tr1l_NOT_USED "")
set(Boost_math_tr1l_LIBS_FRAMEWORKS_DEPS ${Boost_math_tr1l_FRAMEWORKS_FOUND} ${Boost_math_tr1l_SYSTEM_LIBS} ${Boost_math_tr1l_DEPENDENCIES})
conan_package_library_targets("${Boost_math_tr1l_LIBS}"
                              "${Boost_math_tr1l_LIB_DIRS}"
                              "${Boost_math_tr1l_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_tr1l_NOT_USED
                              Boost_math_tr1l_LIB_TARGETS
                              ""
                              "Boost_math_tr1l")

set(Boost_math_tr1l_LINK_LIBS ${Boost_math_tr1l_LIB_TARGETS} ${Boost_math_tr1l_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_tr1f FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_tr1f_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_tr1f_FRAMEWORKS_FOUND "${Boost_math_tr1f_FRAMEWORKS}" "${Boost_math_tr1f_FRAMEWORK_DIRS}")

set(Boost_math_tr1f_LIB_TARGETS "")
set(Boost_math_tr1f_NOT_USED "")
set(Boost_math_tr1f_LIBS_FRAMEWORKS_DEPS ${Boost_math_tr1f_FRAMEWORKS_FOUND} ${Boost_math_tr1f_SYSTEM_LIBS} ${Boost_math_tr1f_DEPENDENCIES})
conan_package_library_targets("${Boost_math_tr1f_LIBS}"
                              "${Boost_math_tr1f_LIB_DIRS}"
                              "${Boost_math_tr1f_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_tr1f_NOT_USED
                              Boost_math_tr1f_LIB_TARGETS
                              ""
                              "Boost_math_tr1f")

set(Boost_math_tr1f_LINK_LIBS ${Boost_math_tr1f_LIB_TARGETS} ${Boost_math_tr1f_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_tr1 FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_tr1_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_tr1_FRAMEWORKS_FOUND "${Boost_math_tr1_FRAMEWORKS}" "${Boost_math_tr1_FRAMEWORK_DIRS}")

set(Boost_math_tr1_LIB_TARGETS "")
set(Boost_math_tr1_NOT_USED "")
set(Boost_math_tr1_LIBS_FRAMEWORKS_DEPS ${Boost_math_tr1_FRAMEWORKS_FOUND} ${Boost_math_tr1_SYSTEM_LIBS} ${Boost_math_tr1_DEPENDENCIES})
conan_package_library_targets("${Boost_math_tr1_LIBS}"
                              "${Boost_math_tr1_LIB_DIRS}"
                              "${Boost_math_tr1_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_tr1_NOT_USED
                              Boost_math_tr1_LIB_TARGETS
                              ""
                              "Boost_math_tr1")

set(Boost_math_tr1_LINK_LIBS ${Boost_math_tr1_LIB_TARGETS} ${Boost_math_tr1_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_c99l FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_c99l_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_c99l_FRAMEWORKS_FOUND "${Boost_math_c99l_FRAMEWORKS}" "${Boost_math_c99l_FRAMEWORK_DIRS}")

set(Boost_math_c99l_LIB_TARGETS "")
set(Boost_math_c99l_NOT_USED "")
set(Boost_math_c99l_LIBS_FRAMEWORKS_DEPS ${Boost_math_c99l_FRAMEWORKS_FOUND} ${Boost_math_c99l_SYSTEM_LIBS} ${Boost_math_c99l_DEPENDENCIES})
conan_package_library_targets("${Boost_math_c99l_LIBS}"
                              "${Boost_math_c99l_LIB_DIRS}"
                              "${Boost_math_c99l_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_c99l_NOT_USED
                              Boost_math_c99l_LIB_TARGETS
                              ""
                              "Boost_math_c99l")

set(Boost_math_c99l_LINK_LIBS ${Boost_math_c99l_LIB_TARGETS} ${Boost_math_c99l_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_c99f FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_c99f_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_c99f_FRAMEWORKS_FOUND "${Boost_math_c99f_FRAMEWORKS}" "${Boost_math_c99f_FRAMEWORK_DIRS}")

set(Boost_math_c99f_LIB_TARGETS "")
set(Boost_math_c99f_NOT_USED "")
set(Boost_math_c99f_LIBS_FRAMEWORKS_DEPS ${Boost_math_c99f_FRAMEWORKS_FOUND} ${Boost_math_c99f_SYSTEM_LIBS} ${Boost_math_c99f_DEPENDENCIES})
conan_package_library_targets("${Boost_math_c99f_LIBS}"
                              "${Boost_math_c99f_LIB_DIRS}"
                              "${Boost_math_c99f_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_c99f_NOT_USED
                              Boost_math_c99f_LIB_TARGETS
                              ""
                              "Boost_math_c99f")

set(Boost_math_c99f_LINK_LIBS ${Boost_math_c99f_LIB_TARGETS} ${Boost_math_c99f_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT math_c99 FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_math_c99_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_math_c99_FRAMEWORKS_FOUND "${Boost_math_c99_FRAMEWORKS}" "${Boost_math_c99_FRAMEWORK_DIRS}")

set(Boost_math_c99_LIB_TARGETS "")
set(Boost_math_c99_NOT_USED "")
set(Boost_math_c99_LIBS_FRAMEWORKS_DEPS ${Boost_math_c99_FRAMEWORKS_FOUND} ${Boost_math_c99_SYSTEM_LIBS} ${Boost_math_c99_DEPENDENCIES})
conan_package_library_targets("${Boost_math_c99_LIBS}"
                              "${Boost_math_c99_LIB_DIRS}"
                              "${Boost_math_c99_LIBS_FRAMEWORKS_DEPS}"
                              Boost_math_c99_NOT_USED
                              Boost_math_c99_LIB_TARGETS
                              ""
                              "Boost_math_c99")

set(Boost_math_c99_LINK_LIBS ${Boost_math_c99_LIB_TARGETS} ${Boost_math_c99_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT log FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_log_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_log_FRAMEWORKS_FOUND "${Boost_log_FRAMEWORKS}" "${Boost_log_FRAMEWORK_DIRS}")

set(Boost_log_LIB_TARGETS "")
set(Boost_log_NOT_USED "")
set(Boost_log_LIBS_FRAMEWORKS_DEPS ${Boost_log_FRAMEWORKS_FOUND} ${Boost_log_SYSTEM_LIBS} ${Boost_log_DEPENDENCIES})
conan_package_library_targets("${Boost_log_LIBS}"
                              "${Boost_log_LIB_DIRS}"
                              "${Boost_log_LIBS_FRAMEWORKS_DEPS}"
                              Boost_log_NOT_USED
                              Boost_log_LIB_TARGETS
                              ""
                              "Boost_log")

set(Boost_log_LINK_LIBS ${Boost_log_LIB_TARGETS} ${Boost_log_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT log_setup FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_log_setup_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_log_setup_FRAMEWORKS_FOUND "${Boost_log_setup_FRAMEWORKS}" "${Boost_log_setup_FRAMEWORK_DIRS}")

set(Boost_log_setup_LIB_TARGETS "")
set(Boost_log_setup_NOT_USED "")
set(Boost_log_setup_LIBS_FRAMEWORKS_DEPS ${Boost_log_setup_FRAMEWORKS_FOUND} ${Boost_log_setup_SYSTEM_LIBS} ${Boost_log_setup_DEPENDENCIES})
conan_package_library_targets("${Boost_log_setup_LIBS}"
                              "${Boost_log_setup_LIB_DIRS}"
                              "${Boost_log_setup_LIBS_FRAMEWORKS_DEPS}"
                              Boost_log_setup_NOT_USED
                              Boost_log_setup_LIB_TARGETS
                              ""
                              "Boost_log_setup")

set(Boost_log_setup_LINK_LIBS ${Boost_log_setup_LIB_TARGETS} ${Boost_log_setup_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT locale FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_locale_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_locale_FRAMEWORKS_FOUND "${Boost_locale_FRAMEWORKS}" "${Boost_locale_FRAMEWORK_DIRS}")

set(Boost_locale_LIB_TARGETS "")
set(Boost_locale_NOT_USED "")
set(Boost_locale_LIBS_FRAMEWORKS_DEPS ${Boost_locale_FRAMEWORKS_FOUND} ${Boost_locale_SYSTEM_LIBS} ${Boost_locale_DEPENDENCIES})
conan_package_library_targets("${Boost_locale_LIBS}"
                              "${Boost_locale_LIB_DIRS}"
                              "${Boost_locale_LIBS_FRAMEWORKS_DEPS}"
                              Boost_locale_NOT_USED
                              Boost_locale_LIB_TARGETS
                              ""
                              "Boost_locale")

set(Boost_locale_LINK_LIBS ${Boost_locale_LIB_TARGETS} ${Boost_locale_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT json FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_json_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_json_FRAMEWORKS_FOUND "${Boost_json_FRAMEWORKS}" "${Boost_json_FRAMEWORK_DIRS}")

set(Boost_json_LIB_TARGETS "")
set(Boost_json_NOT_USED "")
set(Boost_json_LIBS_FRAMEWORKS_DEPS ${Boost_json_FRAMEWORKS_FOUND} ${Boost_json_SYSTEM_LIBS} ${Boost_json_DEPENDENCIES})
conan_package_library_targets("${Boost_json_LIBS}"
                              "${Boost_json_LIB_DIRS}"
                              "${Boost_json_LIBS_FRAMEWORKS_DEPS}"
                              Boost_json_NOT_USED
                              Boost_json_LIB_TARGETS
                              ""
                              "Boost_json")

set(Boost_json_LINK_LIBS ${Boost_json_LIB_TARGETS} ${Boost_json_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT iostreams FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_iostreams_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_iostreams_FRAMEWORKS_FOUND "${Boost_iostreams_FRAMEWORKS}" "${Boost_iostreams_FRAMEWORK_DIRS}")

set(Boost_iostreams_LIB_TARGETS "")
set(Boost_iostreams_NOT_USED "")
set(Boost_iostreams_LIBS_FRAMEWORKS_DEPS ${Boost_iostreams_FRAMEWORKS_FOUND} ${Boost_iostreams_SYSTEM_LIBS} ${Boost_iostreams_DEPENDENCIES})
conan_package_library_targets("${Boost_iostreams_LIBS}"
                              "${Boost_iostreams_LIB_DIRS}"
                              "${Boost_iostreams_LIBS_FRAMEWORKS_DEPS}"
                              Boost_iostreams_NOT_USED
                              Boost_iostreams_LIB_TARGETS
                              ""
                              "Boost_iostreams")

set(Boost_iostreams_LINK_LIBS ${Boost_iostreams_LIB_TARGETS} ${Boost_iostreams_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT graph FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_graph_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_graph_FRAMEWORKS_FOUND "${Boost_graph_FRAMEWORKS}" "${Boost_graph_FRAMEWORK_DIRS}")

set(Boost_graph_LIB_TARGETS "")
set(Boost_graph_NOT_USED "")
set(Boost_graph_LIBS_FRAMEWORKS_DEPS ${Boost_graph_FRAMEWORKS_FOUND} ${Boost_graph_SYSTEM_LIBS} ${Boost_graph_DEPENDENCIES})
conan_package_library_targets("${Boost_graph_LIBS}"
                              "${Boost_graph_LIB_DIRS}"
                              "${Boost_graph_LIBS_FRAMEWORKS_DEPS}"
                              Boost_graph_NOT_USED
                              Boost_graph_LIB_TARGETS
                              ""
                              "Boost_graph")

set(Boost_graph_LINK_LIBS ${Boost_graph_LIB_TARGETS} ${Boost_graph_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT context FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_context_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_context_FRAMEWORKS_FOUND "${Boost_context_FRAMEWORKS}" "${Boost_context_FRAMEWORK_DIRS}")

set(Boost_context_LIB_TARGETS "")
set(Boost_context_NOT_USED "")
set(Boost_context_LIBS_FRAMEWORKS_DEPS ${Boost_context_FRAMEWORKS_FOUND} ${Boost_context_SYSTEM_LIBS} ${Boost_context_DEPENDENCIES})
conan_package_library_targets("${Boost_context_LIBS}"
                              "${Boost_context_LIB_DIRS}"
                              "${Boost_context_LIBS_FRAMEWORKS_DEPS}"
                              Boost_context_NOT_USED
                              Boost_context_LIB_TARGETS
                              ""
                              "Boost_context")

set(Boost_context_LINK_LIBS ${Boost_context_LIB_TARGETS} ${Boost_context_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT fiber FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_fiber_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_fiber_FRAMEWORKS_FOUND "${Boost_fiber_FRAMEWORKS}" "${Boost_fiber_FRAMEWORK_DIRS}")

set(Boost_fiber_LIB_TARGETS "")
set(Boost_fiber_NOT_USED "")
set(Boost_fiber_LIBS_FRAMEWORKS_DEPS ${Boost_fiber_FRAMEWORKS_FOUND} ${Boost_fiber_SYSTEM_LIBS} ${Boost_fiber_DEPENDENCIES})
conan_package_library_targets("${Boost_fiber_LIBS}"
                              "${Boost_fiber_LIB_DIRS}"
                              "${Boost_fiber_LIBS_FRAMEWORKS_DEPS}"
                              Boost_fiber_NOT_USED
                              Boost_fiber_LIB_TARGETS
                              ""
                              "Boost_fiber")

set(Boost_fiber_LINK_LIBS ${Boost_fiber_LIB_TARGETS} ${Boost_fiber_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT fiber_numa FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_fiber_numa_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_fiber_numa_FRAMEWORKS_FOUND "${Boost_fiber_numa_FRAMEWORKS}" "${Boost_fiber_numa_FRAMEWORK_DIRS}")

set(Boost_fiber_numa_LIB_TARGETS "")
set(Boost_fiber_numa_NOT_USED "")
set(Boost_fiber_numa_LIBS_FRAMEWORKS_DEPS ${Boost_fiber_numa_FRAMEWORKS_FOUND} ${Boost_fiber_numa_SYSTEM_LIBS} ${Boost_fiber_numa_DEPENDENCIES})
conan_package_library_targets("${Boost_fiber_numa_LIBS}"
                              "${Boost_fiber_numa_LIB_DIRS}"
                              "${Boost_fiber_numa_LIBS_FRAMEWORKS_DEPS}"
                              Boost_fiber_numa_NOT_USED
                              Boost_fiber_numa_LIB_TARGETS
                              ""
                              "Boost_fiber_numa")

set(Boost_fiber_numa_LINK_LIBS ${Boost_fiber_numa_LIB_TARGETS} ${Boost_fiber_numa_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT coroutine FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_coroutine_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_coroutine_FRAMEWORKS_FOUND "${Boost_coroutine_FRAMEWORKS}" "${Boost_coroutine_FRAMEWORK_DIRS}")

set(Boost_coroutine_LIB_TARGETS "")
set(Boost_coroutine_NOT_USED "")
set(Boost_coroutine_LIBS_FRAMEWORKS_DEPS ${Boost_coroutine_FRAMEWORKS_FOUND} ${Boost_coroutine_SYSTEM_LIBS} ${Boost_coroutine_DEPENDENCIES})
conan_package_library_targets("${Boost_coroutine_LIBS}"
                              "${Boost_coroutine_LIB_DIRS}"
                              "${Boost_coroutine_LIBS_FRAMEWORKS_DEPS}"
                              Boost_coroutine_NOT_USED
                              Boost_coroutine_LIB_TARGETS
                              ""
                              "Boost_coroutine")

set(Boost_coroutine_LINK_LIBS ${Boost_coroutine_LIB_TARGETS} ${Boost_coroutine_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT contract FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_contract_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_contract_FRAMEWORKS_FOUND "${Boost_contract_FRAMEWORKS}" "${Boost_contract_FRAMEWORK_DIRS}")

set(Boost_contract_LIB_TARGETS "")
set(Boost_contract_NOT_USED "")
set(Boost_contract_LIBS_FRAMEWORKS_DEPS ${Boost_contract_FRAMEWORKS_FOUND} ${Boost_contract_SYSTEM_LIBS} ${Boost_contract_DEPENDENCIES})
conan_package_library_targets("${Boost_contract_LIBS}"
                              "${Boost_contract_LIB_DIRS}"
                              "${Boost_contract_LIBS_FRAMEWORKS_DEPS}"
                              Boost_contract_NOT_USED
                              Boost_contract_LIB_TARGETS
                              ""
                              "Boost_contract")

set(Boost_contract_LINK_LIBS ${Boost_contract_LIB_TARGETS} ${Boost_contract_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT boost FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(Boost_boost_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(Boost_boost_FRAMEWORKS_FOUND "${Boost_boost_FRAMEWORKS}" "${Boost_boost_FRAMEWORK_DIRS}")

set(Boost_boost_LIB_TARGETS "")
set(Boost_boost_NOT_USED "")
set(Boost_boost_LIBS_FRAMEWORKS_DEPS ${Boost_boost_FRAMEWORKS_FOUND} ${Boost_boost_SYSTEM_LIBS} ${Boost_boost_DEPENDENCIES})
conan_package_library_targets("${Boost_boost_LIBS}"
                              "${Boost_boost_LIB_DIRS}"
                              "${Boost_boost_LIBS_FRAMEWORKS_DEPS}"
                              Boost_boost_NOT_USED
                              Boost_boost_LIB_TARGETS
                              ""
                              "Boost_boost")

set(Boost_boost_LINK_LIBS ${Boost_boost_LIB_TARGETS} ${Boost_boost_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})


########## TARGETS ##########################################################################
#############################################################################################

########## COMPONENT dynamic_linking TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::dynamic_linking)
        add_library(Boost::dynamic_linking INTERFACE IMPORTED)
        set_target_properties(Boost::dynamic_linking PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_dynamic_linking_INCLUDE_DIRS}")
        set_target_properties(Boost::dynamic_linking PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_dynamic_linking_LIB_DIRS}")
        set_target_properties(Boost::dynamic_linking PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_dynamic_linking_LINK_LIBS};${Boost_dynamic_linking_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::dynamic_linking PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_dynamic_linking_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::dynamic_linking PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_dynamic_linking_COMPILE_OPTIONS_C};${Boost_dynamic_linking_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT disable_autolinking TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::disable_autolinking)
        add_library(Boost::disable_autolinking INTERFACE IMPORTED)
        set_target_properties(Boost::disable_autolinking PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_disable_autolinking_INCLUDE_DIRS}")
        set_target_properties(Boost::disable_autolinking PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_disable_autolinking_LIB_DIRS}")
        set_target_properties(Boost::disable_autolinking PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_disable_autolinking_LINK_LIBS};${Boost_disable_autolinking_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::disable_autolinking PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_disable_autolinking_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::disable_autolinking PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_disable_autolinking_COMPILE_OPTIONS_C};${Boost_disable_autolinking_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT diagnostic_definitions TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::diagnostic_definitions)
        add_library(Boost::diagnostic_definitions INTERFACE IMPORTED)
        set_target_properties(Boost::diagnostic_definitions PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_diagnostic_definitions_INCLUDE_DIRS}")
        set_target_properties(Boost::diagnostic_definitions PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_diagnostic_definitions_LIB_DIRS}")
        set_target_properties(Boost::diagnostic_definitions PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_diagnostic_definitions_LINK_LIBS};${Boost_diagnostic_definitions_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::diagnostic_definitions PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_diagnostic_definitions_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::diagnostic_definitions PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_diagnostic_definitions_COMPILE_OPTIONS_C};${Boost_diagnostic_definitions_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT headers TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::headers)
        add_library(Boost::headers INTERFACE IMPORTED)
        set_target_properties(Boost::headers PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_headers_INCLUDE_DIRS}")
        set_target_properties(Boost::headers PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_headers_LIB_DIRS}")
        set_target_properties(Boost::headers PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_headers_LINK_LIBS};${Boost_headers_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::headers PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_headers_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::headers PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_headers_COMPILE_OPTIONS_C};${Boost_headers_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT _libboost TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::_libboost)
        add_library(Boost::_libboost INTERFACE IMPORTED)
        set_target_properties(Boost::_libboost PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost__libboost_INCLUDE_DIRS}")
        set_target_properties(Boost::_libboost PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost__libboost_LIB_DIRS}")
        set_target_properties(Boost::_libboost PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost__libboost_LINK_LIBS};${Boost__libboost_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::_libboost PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost__libboost_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::_libboost PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost__libboost_COMPILE_OPTIONS_C};${Boost__libboost_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT serialization TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::serialization)
        add_library(Boost::serialization INTERFACE IMPORTED)
        set_target_properties(Boost::serialization PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_serialization_INCLUDE_DIRS}")
        set_target_properties(Boost::serialization PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_serialization_LIB_DIRS}")
        set_target_properties(Boost::serialization PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_serialization_LINK_LIBS};${Boost_serialization_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::serialization PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_serialization_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::serialization PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_serialization_COMPILE_OPTIONS_C};${Boost_serialization_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT wserialization TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::wserialization)
        add_library(Boost::wserialization INTERFACE IMPORTED)
        set_target_properties(Boost::wserialization PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_wserialization_INCLUDE_DIRS}")
        set_target_properties(Boost::wserialization PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_wserialization_LIB_DIRS}")
        set_target_properties(Boost::wserialization PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_wserialization_LINK_LIBS};${Boost_wserialization_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::wserialization PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_wserialization_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::wserialization PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_wserialization_COMPILE_OPTIONS_C};${Boost_wserialization_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT system TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::system)
        add_library(Boost::system INTERFACE IMPORTED)
        set_target_properties(Boost::system PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_system_INCLUDE_DIRS}")
        set_target_properties(Boost::system PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_system_LIB_DIRS}")
        set_target_properties(Boost::system PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_system_LINK_LIBS};${Boost_system_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::system PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_system_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::system PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_system_COMPILE_OPTIONS_C};${Boost_system_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT atomic TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::atomic)
        add_library(Boost::atomic INTERFACE IMPORTED)
        set_target_properties(Boost::atomic PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_atomic_INCLUDE_DIRS}")
        set_target_properties(Boost::atomic PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_atomic_LIB_DIRS}")
        set_target_properties(Boost::atomic PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_atomic_LINK_LIBS};${Boost_atomic_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::atomic PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_atomic_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::atomic PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_atomic_COMPILE_OPTIONS_C};${Boost_atomic_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT filesystem TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::filesystem)
        add_library(Boost::filesystem INTERFACE IMPORTED)
        set_target_properties(Boost::filesystem PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_filesystem_INCLUDE_DIRS}")
        set_target_properties(Boost::filesystem PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_filesystem_LIB_DIRS}")
        set_target_properties(Boost::filesystem PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_filesystem_LINK_LIBS};${Boost_filesystem_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::filesystem PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_filesystem_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::filesystem PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_filesystem_COMPILE_OPTIONS_C};${Boost_filesystem_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT wave TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::wave)
        add_library(Boost::wave INTERFACE IMPORTED)
        set_target_properties(Boost::wave PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_wave_INCLUDE_DIRS}")
        set_target_properties(Boost::wave PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_wave_LIB_DIRS}")
        set_target_properties(Boost::wave PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_wave_LINK_LIBS};${Boost_wave_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::wave PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_wave_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::wave PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_wave_COMPILE_OPTIONS_C};${Boost_wave_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT exception TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::exception)
        add_library(Boost::exception INTERFACE IMPORTED)
        set_target_properties(Boost::exception PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_exception_INCLUDE_DIRS}")
        set_target_properties(Boost::exception PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_exception_LIB_DIRS}")
        set_target_properties(Boost::exception PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_exception_LINK_LIBS};${Boost_exception_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::exception PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_exception_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::exception PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_exception_COMPILE_OPTIONS_C};${Boost_exception_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT test TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::test)
        add_library(Boost::test INTERFACE IMPORTED)
        set_target_properties(Boost::test PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_test_INCLUDE_DIRS}")
        set_target_properties(Boost::test PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_test_LIB_DIRS}")
        set_target_properties(Boost::test PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_test_LINK_LIBS};${Boost_test_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::test PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_test_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::test PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_test_COMPILE_OPTIONS_C};${Boost_test_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT test_exec_monitor TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::test_exec_monitor)
        add_library(Boost::test_exec_monitor INTERFACE IMPORTED)
        set_target_properties(Boost::test_exec_monitor PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_test_exec_monitor_INCLUDE_DIRS}")
        set_target_properties(Boost::test_exec_monitor PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_test_exec_monitor_LIB_DIRS}")
        set_target_properties(Boost::test_exec_monitor PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_test_exec_monitor_LINK_LIBS};${Boost_test_exec_monitor_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::test_exec_monitor PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_test_exec_monitor_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::test_exec_monitor PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_test_exec_monitor_COMPILE_OPTIONS_C};${Boost_test_exec_monitor_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT prg_exec_monitor TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::prg_exec_monitor)
        add_library(Boost::prg_exec_monitor INTERFACE IMPORTED)
        set_target_properties(Boost::prg_exec_monitor PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_prg_exec_monitor_INCLUDE_DIRS}")
        set_target_properties(Boost::prg_exec_monitor PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_prg_exec_monitor_LIB_DIRS}")
        set_target_properties(Boost::prg_exec_monitor PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_prg_exec_monitor_LINK_LIBS};${Boost_prg_exec_monitor_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::prg_exec_monitor PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_prg_exec_monitor_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::prg_exec_monitor PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_prg_exec_monitor_COMPILE_OPTIONS_C};${Boost_prg_exec_monitor_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT unit_test_framework TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::unit_test_framework)
        add_library(Boost::unit_test_framework INTERFACE IMPORTED)
        set_target_properties(Boost::unit_test_framework PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_unit_test_framework_INCLUDE_DIRS}")
        set_target_properties(Boost::unit_test_framework PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_unit_test_framework_LIB_DIRS}")
        set_target_properties(Boost::unit_test_framework PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_unit_test_framework_LINK_LIBS};${Boost_unit_test_framework_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::unit_test_framework PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_unit_test_framework_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::unit_test_framework PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_unit_test_framework_COMPILE_OPTIONS_C};${Boost_unit_test_framework_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT date_time TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::date_time)
        add_library(Boost::date_time INTERFACE IMPORTED)
        set_target_properties(Boost::date_time PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_date_time_INCLUDE_DIRS}")
        set_target_properties(Boost::date_time PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_date_time_LIB_DIRS}")
        set_target_properties(Boost::date_time PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_date_time_LINK_LIBS};${Boost_date_time_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::date_time PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_date_time_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::date_time PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_date_time_COMPILE_OPTIONS_C};${Boost_date_time_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT container TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::container)
        add_library(Boost::container INTERFACE IMPORTED)
        set_target_properties(Boost::container PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_container_INCLUDE_DIRS}")
        set_target_properties(Boost::container PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_container_LIB_DIRS}")
        set_target_properties(Boost::container PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_container_LINK_LIBS};${Boost_container_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::container PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_container_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::container PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_container_COMPILE_OPTIONS_C};${Boost_container_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT chrono TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::chrono)
        add_library(Boost::chrono INTERFACE IMPORTED)
        set_target_properties(Boost::chrono PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_chrono_INCLUDE_DIRS}")
        set_target_properties(Boost::chrono PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_chrono_LIB_DIRS}")
        set_target_properties(Boost::chrono PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_chrono_LINK_LIBS};${Boost_chrono_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::chrono PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_chrono_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::chrono PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_chrono_COMPILE_OPTIONS_C};${Boost_chrono_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT thread TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::thread)
        add_library(Boost::thread INTERFACE IMPORTED)
        set_target_properties(Boost::thread PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_thread_INCLUDE_DIRS}")
        set_target_properties(Boost::thread PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_thread_LIB_DIRS}")
        set_target_properties(Boost::thread PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_thread_LINK_LIBS};${Boost_thread_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::thread PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_thread_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::thread PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_thread_COMPILE_OPTIONS_C};${Boost_thread_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT type_erasure TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::type_erasure)
        add_library(Boost::type_erasure INTERFACE IMPORTED)
        set_target_properties(Boost::type_erasure PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_type_erasure_INCLUDE_DIRS}")
        set_target_properties(Boost::type_erasure PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_type_erasure_LIB_DIRS}")
        set_target_properties(Boost::type_erasure PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_type_erasure_LINK_LIBS};${Boost_type_erasure_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::type_erasure PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_type_erasure_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::type_erasure PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_type_erasure_COMPILE_OPTIONS_C};${Boost_type_erasure_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT timer TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::timer)
        add_library(Boost::timer INTERFACE IMPORTED)
        set_target_properties(Boost::timer PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_timer_INCLUDE_DIRS}")
        set_target_properties(Boost::timer PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_timer_LIB_DIRS}")
        set_target_properties(Boost::timer PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_timer_LINK_LIBS};${Boost_timer_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::timer PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_timer_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::timer PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_timer_COMPILE_OPTIONS_C};${Boost_timer_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT stacktrace TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::stacktrace)
        add_library(Boost::stacktrace INTERFACE IMPORTED)
        set_target_properties(Boost::stacktrace PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_stacktrace_INCLUDE_DIRS}")
        set_target_properties(Boost::stacktrace PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_stacktrace_LIB_DIRS}")
        set_target_properties(Boost::stacktrace PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_stacktrace_LINK_LIBS};${Boost_stacktrace_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::stacktrace PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_stacktrace_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::stacktrace PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_stacktrace_COMPILE_OPTIONS_C};${Boost_stacktrace_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT stacktrace_windbg_cached TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::stacktrace_windbg_cached)
        add_library(Boost::stacktrace_windbg_cached INTERFACE IMPORTED)
        set_target_properties(Boost::stacktrace_windbg_cached PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_stacktrace_windbg_cached_INCLUDE_DIRS}")
        set_target_properties(Boost::stacktrace_windbg_cached PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_stacktrace_windbg_cached_LIB_DIRS}")
        set_target_properties(Boost::stacktrace_windbg_cached PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_stacktrace_windbg_cached_LINK_LIBS};${Boost_stacktrace_windbg_cached_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::stacktrace_windbg_cached PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_stacktrace_windbg_cached_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::stacktrace_windbg_cached PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_stacktrace_windbg_cached_COMPILE_OPTIONS_C};${Boost_stacktrace_windbg_cached_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT stacktrace_windbg TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::stacktrace_windbg)
        add_library(Boost::stacktrace_windbg INTERFACE IMPORTED)
        set_target_properties(Boost::stacktrace_windbg PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_stacktrace_windbg_INCLUDE_DIRS}")
        set_target_properties(Boost::stacktrace_windbg PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_stacktrace_windbg_LIB_DIRS}")
        set_target_properties(Boost::stacktrace_windbg PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_stacktrace_windbg_LINK_LIBS};${Boost_stacktrace_windbg_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::stacktrace_windbg PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_stacktrace_windbg_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::stacktrace_windbg PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_stacktrace_windbg_COMPILE_OPTIONS_C};${Boost_stacktrace_windbg_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT stacktrace_noop TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::stacktrace_noop)
        add_library(Boost::stacktrace_noop INTERFACE IMPORTED)
        set_target_properties(Boost::stacktrace_noop PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_stacktrace_noop_INCLUDE_DIRS}")
        set_target_properties(Boost::stacktrace_noop PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_stacktrace_noop_LIB_DIRS}")
        set_target_properties(Boost::stacktrace_noop PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_stacktrace_noop_LINK_LIBS};${Boost_stacktrace_noop_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::stacktrace_noop PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_stacktrace_noop_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::stacktrace_noop PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_stacktrace_noop_COMPILE_OPTIONS_C};${Boost_stacktrace_noop_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT regex TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::regex)
        add_library(Boost::regex INTERFACE IMPORTED)
        set_target_properties(Boost::regex PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_regex_INCLUDE_DIRS}")
        set_target_properties(Boost::regex PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_regex_LIB_DIRS}")
        set_target_properties(Boost::regex PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_regex_LINK_LIBS};${Boost_regex_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::regex PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_regex_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::regex PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_regex_COMPILE_OPTIONS_C};${Boost_regex_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT random TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::random)
        add_library(Boost::random INTERFACE IMPORTED)
        set_target_properties(Boost::random PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_random_INCLUDE_DIRS}")
        set_target_properties(Boost::random PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_random_LIB_DIRS}")
        set_target_properties(Boost::random PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_random_LINK_LIBS};${Boost_random_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::random PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_random_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::random PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_random_COMPILE_OPTIONS_C};${Boost_random_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT program_options TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::program_options)
        add_library(Boost::program_options INTERFACE IMPORTED)
        set_target_properties(Boost::program_options PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_program_options_INCLUDE_DIRS}")
        set_target_properties(Boost::program_options PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_program_options_LIB_DIRS}")
        set_target_properties(Boost::program_options PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_program_options_LINK_LIBS};${Boost_program_options_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::program_options PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_program_options_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::program_options PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_program_options_COMPILE_OPTIONS_C};${Boost_program_options_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT nowide TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::nowide)
        add_library(Boost::nowide INTERFACE IMPORTED)
        set_target_properties(Boost::nowide PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_nowide_INCLUDE_DIRS}")
        set_target_properties(Boost::nowide PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_nowide_LIB_DIRS}")
        set_target_properties(Boost::nowide PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_nowide_LINK_LIBS};${Boost_nowide_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::nowide PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_nowide_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::nowide PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_nowide_COMPILE_OPTIONS_C};${Boost_nowide_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math)
        add_library(Boost::math INTERFACE IMPORTED)
        set_target_properties(Boost::math PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_INCLUDE_DIRS}")
        set_target_properties(Boost::math PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_LIB_DIRS}")
        set_target_properties(Boost::math PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_LINK_LIBS};${Boost_math_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_COMPILE_OPTIONS_C};${Boost_math_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_tr1l TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_tr1l)
        add_library(Boost::math_tr1l INTERFACE IMPORTED)
        set_target_properties(Boost::math_tr1l PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_tr1l_INCLUDE_DIRS}")
        set_target_properties(Boost::math_tr1l PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_tr1l_LIB_DIRS}")
        set_target_properties(Boost::math_tr1l PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_tr1l_LINK_LIBS};${Boost_math_tr1l_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_tr1l PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_tr1l_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_tr1l PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_tr1l_COMPILE_OPTIONS_C};${Boost_math_tr1l_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_tr1f TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_tr1f)
        add_library(Boost::math_tr1f INTERFACE IMPORTED)
        set_target_properties(Boost::math_tr1f PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_tr1f_INCLUDE_DIRS}")
        set_target_properties(Boost::math_tr1f PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_tr1f_LIB_DIRS}")
        set_target_properties(Boost::math_tr1f PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_tr1f_LINK_LIBS};${Boost_math_tr1f_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_tr1f PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_tr1f_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_tr1f PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_tr1f_COMPILE_OPTIONS_C};${Boost_math_tr1f_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_tr1 TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_tr1)
        add_library(Boost::math_tr1 INTERFACE IMPORTED)
        set_target_properties(Boost::math_tr1 PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_tr1_INCLUDE_DIRS}")
        set_target_properties(Boost::math_tr1 PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_tr1_LIB_DIRS}")
        set_target_properties(Boost::math_tr1 PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_tr1_LINK_LIBS};${Boost_math_tr1_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_tr1 PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_tr1_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_tr1 PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_tr1_COMPILE_OPTIONS_C};${Boost_math_tr1_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_c99l TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_c99l)
        add_library(Boost::math_c99l INTERFACE IMPORTED)
        set_target_properties(Boost::math_c99l PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_c99l_INCLUDE_DIRS}")
        set_target_properties(Boost::math_c99l PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_c99l_LIB_DIRS}")
        set_target_properties(Boost::math_c99l PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_c99l_LINK_LIBS};${Boost_math_c99l_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_c99l PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_c99l_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_c99l PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_c99l_COMPILE_OPTIONS_C};${Boost_math_c99l_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_c99f TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_c99f)
        add_library(Boost::math_c99f INTERFACE IMPORTED)
        set_target_properties(Boost::math_c99f PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_c99f_INCLUDE_DIRS}")
        set_target_properties(Boost::math_c99f PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_c99f_LIB_DIRS}")
        set_target_properties(Boost::math_c99f PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_c99f_LINK_LIBS};${Boost_math_c99f_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_c99f PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_c99f_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_c99f PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_c99f_COMPILE_OPTIONS_C};${Boost_math_c99f_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT math_c99 TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::math_c99)
        add_library(Boost::math_c99 INTERFACE IMPORTED)
        set_target_properties(Boost::math_c99 PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_math_c99_INCLUDE_DIRS}")
        set_target_properties(Boost::math_c99 PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_math_c99_LIB_DIRS}")
        set_target_properties(Boost::math_c99 PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_math_c99_LINK_LIBS};${Boost_math_c99_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::math_c99 PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_math_c99_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::math_c99 PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_math_c99_COMPILE_OPTIONS_C};${Boost_math_c99_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT log TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::log)
        add_library(Boost::log INTERFACE IMPORTED)
        set_target_properties(Boost::log PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_log_INCLUDE_DIRS}")
        set_target_properties(Boost::log PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_log_LIB_DIRS}")
        set_target_properties(Boost::log PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_log_LINK_LIBS};${Boost_log_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::log PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_log_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::log PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_log_COMPILE_OPTIONS_C};${Boost_log_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT log_setup TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::log_setup)
        add_library(Boost::log_setup INTERFACE IMPORTED)
        set_target_properties(Boost::log_setup PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_log_setup_INCLUDE_DIRS}")
        set_target_properties(Boost::log_setup PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_log_setup_LIB_DIRS}")
        set_target_properties(Boost::log_setup PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_log_setup_LINK_LIBS};${Boost_log_setup_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::log_setup PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_log_setup_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::log_setup PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_log_setup_COMPILE_OPTIONS_C};${Boost_log_setup_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT locale TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::locale)
        add_library(Boost::locale INTERFACE IMPORTED)
        set_target_properties(Boost::locale PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_locale_INCLUDE_DIRS}")
        set_target_properties(Boost::locale PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_locale_LIB_DIRS}")
        set_target_properties(Boost::locale PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_locale_LINK_LIBS};${Boost_locale_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::locale PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_locale_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::locale PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_locale_COMPILE_OPTIONS_C};${Boost_locale_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT json TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::json)
        add_library(Boost::json INTERFACE IMPORTED)
        set_target_properties(Boost::json PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_json_INCLUDE_DIRS}")
        set_target_properties(Boost::json PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_json_LIB_DIRS}")
        set_target_properties(Boost::json PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_json_LINK_LIBS};${Boost_json_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::json PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_json_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::json PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_json_COMPILE_OPTIONS_C};${Boost_json_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT iostreams TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::iostreams)
        add_library(Boost::iostreams INTERFACE IMPORTED)
        set_target_properties(Boost::iostreams PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_iostreams_INCLUDE_DIRS}")
        set_target_properties(Boost::iostreams PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_iostreams_LIB_DIRS}")
        set_target_properties(Boost::iostreams PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_iostreams_LINK_LIBS};${Boost_iostreams_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::iostreams PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_iostreams_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::iostreams PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_iostreams_COMPILE_OPTIONS_C};${Boost_iostreams_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT graph TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::graph)
        add_library(Boost::graph INTERFACE IMPORTED)
        set_target_properties(Boost::graph PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_graph_INCLUDE_DIRS}")
        set_target_properties(Boost::graph PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_graph_LIB_DIRS}")
        set_target_properties(Boost::graph PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_graph_LINK_LIBS};${Boost_graph_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::graph PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_graph_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::graph PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_graph_COMPILE_OPTIONS_C};${Boost_graph_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT context TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::context)
        add_library(Boost::context INTERFACE IMPORTED)
        set_target_properties(Boost::context PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_context_INCLUDE_DIRS}")
        set_target_properties(Boost::context PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_context_LIB_DIRS}")
        set_target_properties(Boost::context PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_context_LINK_LIBS};${Boost_context_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::context PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_context_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::context PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_context_COMPILE_OPTIONS_C};${Boost_context_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT fiber TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::fiber)
        add_library(Boost::fiber INTERFACE IMPORTED)
        set_target_properties(Boost::fiber PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_fiber_INCLUDE_DIRS}")
        set_target_properties(Boost::fiber PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_fiber_LIB_DIRS}")
        set_target_properties(Boost::fiber PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_fiber_LINK_LIBS};${Boost_fiber_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::fiber PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_fiber_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::fiber PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_fiber_COMPILE_OPTIONS_C};${Boost_fiber_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT fiber_numa TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::fiber_numa)
        add_library(Boost::fiber_numa INTERFACE IMPORTED)
        set_target_properties(Boost::fiber_numa PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_fiber_numa_INCLUDE_DIRS}")
        set_target_properties(Boost::fiber_numa PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_fiber_numa_LIB_DIRS}")
        set_target_properties(Boost::fiber_numa PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_fiber_numa_LINK_LIBS};${Boost_fiber_numa_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::fiber_numa PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_fiber_numa_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::fiber_numa PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_fiber_numa_COMPILE_OPTIONS_C};${Boost_fiber_numa_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT coroutine TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::coroutine)
        add_library(Boost::coroutine INTERFACE IMPORTED)
        set_target_properties(Boost::coroutine PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_coroutine_INCLUDE_DIRS}")
        set_target_properties(Boost::coroutine PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_coroutine_LIB_DIRS}")
        set_target_properties(Boost::coroutine PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_coroutine_LINK_LIBS};${Boost_coroutine_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::coroutine PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_coroutine_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::coroutine PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_coroutine_COMPILE_OPTIONS_C};${Boost_coroutine_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT contract TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::contract)
        add_library(Boost::contract INTERFACE IMPORTED)
        set_target_properties(Boost::contract PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_contract_INCLUDE_DIRS}")
        set_target_properties(Boost::contract PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_contract_LIB_DIRS}")
        set_target_properties(Boost::contract PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_contract_LINK_LIBS};${Boost_contract_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::contract PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_contract_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::contract PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_contract_COMPILE_OPTIONS_C};${Boost_contract_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT boost TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET Boost::boost)
        add_library(Boost::boost INTERFACE IMPORTED)
        set_target_properties(Boost::boost PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${Boost_boost_INCLUDE_DIRS}")
        set_target_properties(Boost::boost PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${Boost_boost_LIB_DIRS}")
        set_target_properties(Boost::boost PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${Boost_boost_LINK_LIBS};${Boost_boost_LINKER_FLAGS_LIST}")
        set_target_properties(Boost::boost PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${Boost_boost_COMPILE_DEFINITIONS}")
        set_target_properties(Boost::boost PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${Boost_boost_COMPILE_OPTIONS_C};${Boost_boost_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## GLOBAL TARGET ####################################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    if(NOT TARGET Boost::Boost)
        add_library(Boost::Boost INTERFACE IMPORTED)
    endif()
    set_property(TARGET Boost::Boost APPEND PROPERTY
                 INTERFACE_LINK_LIBRARIES "${Boost_COMPONENTS}")
endif()

########## BUILD MODULES ####################################################################
#############################################################################################
########## COMPONENT dynamic_linking BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_dynamic_linking_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT disable_autolinking BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_disable_autolinking_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT diagnostic_definitions BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_diagnostic_definitions_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT headers BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_headers_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT _libboost BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost__libboost_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT serialization BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_serialization_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT wserialization BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_wserialization_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT system BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_system_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT atomic BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_atomic_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT filesystem BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_filesystem_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT wave BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_wave_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT exception BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_exception_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT test BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_test_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT test_exec_monitor BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_test_exec_monitor_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT prg_exec_monitor BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_prg_exec_monitor_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT unit_test_framework BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_unit_test_framework_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT date_time BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_date_time_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT container BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_container_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT chrono BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_chrono_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT thread BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_thread_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT type_erasure BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_type_erasure_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT timer BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_timer_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT stacktrace BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_stacktrace_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT stacktrace_windbg_cached BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_stacktrace_windbg_cached_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT stacktrace_windbg BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_stacktrace_windbg_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT stacktrace_noop BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_stacktrace_noop_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT regex BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_regex_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT random BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_random_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT program_options BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_program_options_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT nowide BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_nowide_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_tr1l BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_tr1l_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_tr1f BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_tr1f_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_tr1 BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_tr1_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_c99l BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_c99l_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_c99f BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_c99f_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT math_c99 BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_math_c99_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT log BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_log_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT log_setup BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_log_setup_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT locale BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_locale_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT json BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_json_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT iostreams BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_iostreams_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT graph BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_graph_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT context BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_context_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT fiber BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_fiber_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT fiber_numa BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_fiber_numa_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT coroutine BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_coroutine_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT contract BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_contract_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT boost BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${Boost_boost_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
