########## MACROS ###########################################################################
#############################################################################################

function(conan_message MESSAGE_OUTPUT)
    if(NOT CONAN_CMAKE_SILENT_OUTPUT)
        message(${ARGV${0}})
    endif()
endfunction()


macro(conan_find_apple_frameworks FRAMEWORKS_FOUND FRAMEWORKS FRAMEWORKS_DIRS)
    if(APPLE)
        foreach(_FRAMEWORK ${FRAMEWORKS})
            # https://cmake.org/pipermail/cmake-developers/2017-August/030199.html
            find_library(CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND NAMES ${_FRAMEWORK} PATHS ${FRAMEWORKS_DIRS} CMAKE_FIND_ROOT_PATH_BOTH)
            if(CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND)
                list(APPEND ${FRAMEWORKS_FOUND} ${CONAN_FRAMEWORK_${_FRAMEWORK}_FOUND})
            else()
                message(FATAL_ERROR "Framework library ${_FRAMEWORK} not found in paths: ${FRAMEWORKS_DIRS}")
            endif()
        endforeach()
    endif()
endmacro()


function(conan_package_library_targets libraries package_libdir deps out_libraries out_libraries_target build_type package_name)
    unset(_CONAN_ACTUAL_TARGETS CACHE)
    unset(_CONAN_FOUND_SYSTEM_LIBS CACHE)
    foreach(_LIBRARY_NAME ${libraries})
        find_library(CONAN_FOUND_LIBRARY NAMES ${_LIBRARY_NAME} PATHS ${package_libdir}
                     NO_DEFAULT_PATH NO_CMAKE_FIND_ROOT_PATH)
        if(CONAN_FOUND_LIBRARY)
            conan_message(STATUS "Library ${_LIBRARY_NAME} found ${CONAN_FOUND_LIBRARY}")
            list(APPEND _out_libraries ${CONAN_FOUND_LIBRARY})
            if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
                # Create a micro-target for each lib/a found
                string(REGEX REPLACE "[^A-Za-z0-9.+_-]" "_" _LIBRARY_NAME ${_LIBRARY_NAME})
                set(_LIB_NAME CONAN_LIB::${package_name}_${_LIBRARY_NAME}${build_type})
                if(NOT TARGET ${_LIB_NAME})
                    # Create a micro-target for each lib/a found
                    add_library(${_LIB_NAME} UNKNOWN IMPORTED)
                    set_target_properties(${_LIB_NAME} PROPERTIES IMPORTED_LOCATION ${CONAN_FOUND_LIBRARY})
                    set(_CONAN_ACTUAL_TARGETS ${_CONAN_ACTUAL_TARGETS} ${_LIB_NAME})
                else()
                    conan_message(STATUS "Skipping already existing target: ${_LIB_NAME}")
                endif()
                list(APPEND _out_libraries_target ${_LIB_NAME})
            endif()
            conan_message(STATUS "Found: ${CONAN_FOUND_LIBRARY}")
        else()
            conan_message(STATUS "Library ${_LIBRARY_NAME} not found in package, might be system one")
            list(APPEND _out_libraries_target ${_LIBRARY_NAME})
            list(APPEND _out_libraries ${_LIBRARY_NAME})
            set(_CONAN_FOUND_SYSTEM_LIBS "${_CONAN_FOUND_SYSTEM_LIBS};${_LIBRARY_NAME}")
        endif()
        unset(CONAN_FOUND_LIBRARY CACHE)
    endforeach()

    if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
        # Add all dependencies to all targets
        string(REPLACE " " ";" deps_list "${deps}")
        foreach(_CONAN_ACTUAL_TARGET ${_CONAN_ACTUAL_TARGETS})
            set_property(TARGET ${_CONAN_ACTUAL_TARGET} PROPERTY INTERFACE_LINK_LIBRARIES "${_CONAN_FOUND_SYSTEM_LIBS};${deps_list}")
        endforeach()
    endif()

    set(${out_libraries} ${_out_libraries} PARENT_SCOPE)
    set(${out_libraries_target} ${_out_libraries_target} PARENT_SCOPE)
endfunction()


########### FOUND PACKAGE ###################################################################
#############################################################################################

include(FindPackageHandleStandardArgs)

conan_message(STATUS "Conan: Using autogenerated Findbenchmark.cmake")
set(benchmark_FOUND 1)
set(benchmark_VERSION "1.7.1")

find_package_handle_standard_args(benchmark REQUIRED_VARS
                                  benchmark_VERSION VERSION_VAR benchmark_VERSION)
mark_as_advanced(benchmark_FOUND benchmark_VERSION)

set(benchmark_COMPONENTS benchmark::benchmark_main benchmark::_benchmark)

if(benchmark_FIND_COMPONENTS)
    foreach(_FIND_COMPONENT ${benchmark_FIND_COMPONENTS})
        list(FIND benchmark_COMPONENTS "benchmark::${_FIND_COMPONENT}" _index)
        if(${_index} EQUAL -1)
            conan_message(FATAL_ERROR "Conan: Component '${_FIND_COMPONENT}' NOT found in package 'benchmark'")
        else()
            conan_message(STATUS "Conan: Component '${_FIND_COMPONENT}' found in package 'benchmark'")
        endif()
    endforeach()
endif()

########### VARIABLES #######################################################################
#############################################################################################


set(benchmark_INCLUDE_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_INCLUDE_DIR "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_INCLUDES "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_RES_DIRS )
set(benchmark_DEFINITIONS "-DBENCHMARK_STATIC_DEFINE")
set(benchmark_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)
set(benchmark_COMPILE_DEFINITIONS "BENCHMARK_STATIC_DEFINE")
set(benchmark_COMPILE_OPTIONS_LIST "" "")
set(benchmark_COMPILE_OPTIONS_C "")
set(benchmark_COMPILE_OPTIONS_CXX "")
set(benchmark_LIBRARIES_TARGETS "") # Will be filled later, if CMake 3
set(benchmark_LIBRARIES "") # Will be filled later
set(benchmark_LIBS "") # Same as benchmark_LIBRARIES
set(benchmark_SYSTEM_LIBS shlwapi)
set(benchmark_FRAMEWORK_DIRS )
set(benchmark_FRAMEWORKS )
set(benchmark_FRAMEWORKS_FOUND "") # Will be filled later
set(benchmark_BUILD_MODULES_PATHS )

conan_find_apple_frameworks(benchmark_FRAMEWORKS_FOUND "${benchmark_FRAMEWORKS}" "${benchmark_FRAMEWORK_DIRS}")

mark_as_advanced(benchmark_INCLUDE_DIRS
                 benchmark_INCLUDE_DIR
                 benchmark_INCLUDES
                 benchmark_DEFINITIONS
                 benchmark_LINKER_FLAGS_LIST
                 benchmark_COMPILE_DEFINITIONS
                 benchmark_COMPILE_OPTIONS_LIST
                 benchmark_LIBRARIES
                 benchmark_LIBS
                 benchmark_LIBRARIES_TARGETS)

# Find the real .lib/.a and add them to benchmark_LIBS and benchmark_LIBRARY_LIST
set(benchmark_LIBRARY_LIST benchmark_main benchmark)
set(benchmark_LIB_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/lib")

# Gather all the libraries that should be linked to the targets (do not touch existing variables):
set(_benchmark_DEPENDENCIES "${benchmark_FRAMEWORKS_FOUND} ${benchmark_SYSTEM_LIBS} ")

conan_package_library_targets("${benchmark_LIBRARY_LIST}"  # libraries
                              "${benchmark_LIB_DIRS}"      # package_libdir
                              "${_benchmark_DEPENDENCIES}"  # deps
                              benchmark_LIBRARIES            # out_libraries
                              benchmark_LIBRARIES_TARGETS    # out_libraries_targets
                              ""                          # build_type
                              "benchmark")                                      # package_name

set(benchmark_LIBS ${benchmark_LIBRARIES})

foreach(_FRAMEWORK ${benchmark_FRAMEWORKS_FOUND})
    list(APPEND benchmark_LIBRARIES_TARGETS ${_FRAMEWORK})
    list(APPEND benchmark_LIBRARIES ${_FRAMEWORK})
endforeach()

foreach(_SYSTEM_LIB ${benchmark_SYSTEM_LIBS})
    list(APPEND benchmark_LIBRARIES_TARGETS ${_SYSTEM_LIB})
    list(APPEND benchmark_LIBRARIES ${_SYSTEM_LIB})
endforeach()

# We need to add our requirements too
set(benchmark_LIBRARIES_TARGETS "${benchmark_LIBRARIES_TARGETS};")
set(benchmark_LIBRARIES "${benchmark_LIBRARIES};")

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})


########### COMPONENT _benchmark VARIABLES #############################################

set(benchmark__benchmark_INCLUDE_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark__benchmark_INCLUDE_DIR "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark__benchmark_INCLUDES "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark__benchmark_LIB_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/lib")
set(benchmark__benchmark_RES_DIRS )
set(benchmark__benchmark_DEFINITIONS "-DBENCHMARK_STATIC_DEFINE")
set(benchmark__benchmark_COMPILE_DEFINITIONS "BENCHMARK_STATIC_DEFINE")
set(benchmark__benchmark_COMPILE_OPTIONS_C "")
set(benchmark__benchmark_COMPILE_OPTIONS_CXX "")
set(benchmark__benchmark_LIBS benchmark)
set(benchmark__benchmark_SYSTEM_LIBS shlwapi)
set(benchmark__benchmark_FRAMEWORK_DIRS )
set(benchmark__benchmark_FRAMEWORKS )
set(benchmark__benchmark_BUILD_MODULES_PATHS )
set(benchmark__benchmark_DEPENDENCIES )
set(benchmark__benchmark_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)

########### COMPONENT benchmark_main VARIABLES #############################################

set(benchmark_benchmark_main_INCLUDE_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_benchmark_main_INCLUDE_DIR "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_benchmark_main_INCLUDES "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/include")
set(benchmark_benchmark_main_LIB_DIRS "C:/Users/Quarter/.conan/data/benchmark/1.7.1/_/_/package/4bc064972e1201d5d0a42e623c4a2a79d01b6f0b/lib")
set(benchmark_benchmark_main_RES_DIRS )
set(benchmark_benchmark_main_DEFINITIONS )
set(benchmark_benchmark_main_COMPILE_DEFINITIONS )
set(benchmark_benchmark_main_COMPILE_OPTIONS_C "")
set(benchmark_benchmark_main_COMPILE_OPTIONS_CXX "")
set(benchmark_benchmark_main_LIBS benchmark_main)
set(benchmark_benchmark_main_SYSTEM_LIBS )
set(benchmark_benchmark_main_FRAMEWORK_DIRS )
set(benchmark_benchmark_main_FRAMEWORKS )
set(benchmark_benchmark_main_BUILD_MODULES_PATHS )
set(benchmark_benchmark_main_DEPENDENCIES benchmark::_benchmark)
set(benchmark_benchmark_main_LINKER_FLAGS_LIST
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,SHARED_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,MODULE_LIBRARY>:>"
        "$<$<STREQUAL:$<TARGET_PROPERTY:TYPE>,EXECUTABLE>:>"
)


########## FIND PACKAGE DEPENDENCY ##########################################################
#############################################################################################

include(CMakeFindDependencyMacro)


########## FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #######################################
#############################################################################################

########## COMPONENT _benchmark FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(benchmark__benchmark_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(benchmark__benchmark_FRAMEWORKS_FOUND "${benchmark__benchmark_FRAMEWORKS}" "${benchmark__benchmark_FRAMEWORK_DIRS}")

set(benchmark__benchmark_LIB_TARGETS "")
set(benchmark__benchmark_NOT_USED "")
set(benchmark__benchmark_LIBS_FRAMEWORKS_DEPS ${benchmark__benchmark_FRAMEWORKS_FOUND} ${benchmark__benchmark_SYSTEM_LIBS} ${benchmark__benchmark_DEPENDENCIES})
conan_package_library_targets("${benchmark__benchmark_LIBS}"
                              "${benchmark__benchmark_LIB_DIRS}"
                              "${benchmark__benchmark_LIBS_FRAMEWORKS_DEPS}"
                              benchmark__benchmark_NOT_USED
                              benchmark__benchmark_LIB_TARGETS
                              ""
                              "benchmark__benchmark")

set(benchmark__benchmark_LINK_LIBS ${benchmark__benchmark_LIB_TARGETS} ${benchmark__benchmark_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})

########## COMPONENT benchmark_main FIND LIBRARIES & FRAMEWORKS / DYNAMIC VARS #############

set(benchmark_benchmark_main_FRAMEWORKS_FOUND "")
conan_find_apple_frameworks(benchmark_benchmark_main_FRAMEWORKS_FOUND "${benchmark_benchmark_main_FRAMEWORKS}" "${benchmark_benchmark_main_FRAMEWORK_DIRS}")

set(benchmark_benchmark_main_LIB_TARGETS "")
set(benchmark_benchmark_main_NOT_USED "")
set(benchmark_benchmark_main_LIBS_FRAMEWORKS_DEPS ${benchmark_benchmark_main_FRAMEWORKS_FOUND} ${benchmark_benchmark_main_SYSTEM_LIBS} ${benchmark_benchmark_main_DEPENDENCIES})
conan_package_library_targets("${benchmark_benchmark_main_LIBS}"
                              "${benchmark_benchmark_main_LIB_DIRS}"
                              "${benchmark_benchmark_main_LIBS_FRAMEWORKS_DEPS}"
                              benchmark_benchmark_main_NOT_USED
                              benchmark_benchmark_main_LIB_TARGETS
                              ""
                              "benchmark_benchmark_main")

set(benchmark_benchmark_main_LINK_LIBS ${benchmark_benchmark_main_LIB_TARGETS} ${benchmark_benchmark_main_LIBS_FRAMEWORKS_DEPS})

set(CMAKE_MODULE_PATH  ${CMAKE_MODULE_PATH})
set(CMAKE_PREFIX_PATH  ${CMAKE_PREFIX_PATH})


########## TARGETS ##########################################################################
#############################################################################################

########## COMPONENT _benchmark TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET benchmark::_benchmark)
        add_library(benchmark::_benchmark INTERFACE IMPORTED)
        set_target_properties(benchmark::_benchmark PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${benchmark__benchmark_INCLUDE_DIRS}")
        set_target_properties(benchmark::_benchmark PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${benchmark__benchmark_LIB_DIRS}")
        set_target_properties(benchmark::_benchmark PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${benchmark__benchmark_LINK_LIBS};${benchmark__benchmark_LINKER_FLAGS_LIST}")
        set_target_properties(benchmark::_benchmark PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${benchmark__benchmark_COMPILE_DEFINITIONS}")
        set_target_properties(benchmark::_benchmark PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${benchmark__benchmark_COMPILE_OPTIONS_C};${benchmark__benchmark_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## COMPONENT benchmark_main TARGET #################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    # Target approach
    if(NOT TARGET benchmark::benchmark_main)
        add_library(benchmark::benchmark_main INTERFACE IMPORTED)
        set_target_properties(benchmark::benchmark_main PROPERTIES INTERFACE_INCLUDE_DIRECTORIES
                              "${benchmark_benchmark_main_INCLUDE_DIRS}")
        set_target_properties(benchmark::benchmark_main PROPERTIES INTERFACE_LINK_DIRECTORIES
                              "${benchmark_benchmark_main_LIB_DIRS}")
        set_target_properties(benchmark::benchmark_main PROPERTIES INTERFACE_LINK_LIBRARIES
                              "${benchmark_benchmark_main_LINK_LIBS};${benchmark_benchmark_main_LINKER_FLAGS_LIST}")
        set_target_properties(benchmark::benchmark_main PROPERTIES INTERFACE_COMPILE_DEFINITIONS
                              "${benchmark_benchmark_main_COMPILE_DEFINITIONS}")
        set_target_properties(benchmark::benchmark_main PROPERTIES INTERFACE_COMPILE_OPTIONS
                              "${benchmark_benchmark_main_COMPILE_OPTIONS_C};${benchmark_benchmark_main_COMPILE_OPTIONS_CXX}")
    endif()
endif()

########## GLOBAL TARGET ####################################################################

if(NOT ${CMAKE_VERSION} VERSION_LESS "3.0")
    if(NOT TARGET benchmark::benchmark)
        add_library(benchmark::benchmark INTERFACE IMPORTED)
    endif()
    set_property(TARGET benchmark::benchmark APPEND PROPERTY
                 INTERFACE_LINK_LIBRARIES "${benchmark_COMPONENTS}")
endif()

########## BUILD MODULES ####################################################################
#############################################################################################
########## COMPONENT _benchmark BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${benchmark__benchmark_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
########## COMPONENT benchmark_main BUILD MODULES ##########################################

foreach(_BUILD_MODULE_PATH ${benchmark_benchmark_main_BUILD_MODULES_PATHS})
    include(${_BUILD_MODULE_PATH})
endforeach()
